@@ -81,25 +81,26 @@ struct swit anoyes[] = {
  * nmh constants
  */
 
-char   *components = "components";
-char   *current = "cur";
-char   *defalt = "inbox";
-char   *digestcomps = "digestcomps";
-char   *distcomps = "distcomps";
-char   *draft = "draft";
-char   *forwcomps = "forwcomps";
-char   *inbox = "inbox";
-char   *mh_defaults = nmhetcdir (/mh.profile);
-char   *mh_profile = ".mh_profile";
-char   *mhlformat = "mhl.format";
-char   *mhlforward = "mhl.forward";
-char   *nsequence = "Sequence-Negation";
-char   *pfolder = "Current-Folder";
-char   *psequence = "Previous-Sequence";
-char   *rcvdistcomps = "rcvdistcomps";
-char   *replcomps = "replcomps";
-char   *usequence = "Unseen-Sequence";
-char   *mhlibdir = NMHLIBDIR;
+char *components = "components";
+char *current = "cur";
+char *defalt = "inbox";
+char *digestcomps = "digestcomps";
+char *distcomps = "distcomps";
+char *draft = "draft";
+char *forwcomps = "forwcomps";
+char *inbox = "inbox";
+char *mh_defaults = nmhetcdir (/mh.profile);
+char *mh_profile = ".mh_profile";
+char *mhlformat = "mhl.format";
+char *mhlforward = "mhl.forward";
+char *nsequence = "Sequence-Negation";
+char *pfolder = "Current-Folder";
+char *psequence = "Previous-Sequence";
+char *rcvdistcomps = "rcvdistcomps";
+char *replcomps = "replcomps";
+char *usequence = "Unseen-Sequence";
+char *mhlibdir = NMHLIBDIR;
+char *mhetcdir = NMHETCDIR;
 
 /* 
  * nmh not-so constants
@@ -128,6 +129,11 @@ struct node *m_defs;	/* profile/context structure  */
  * nmh processes
  */
 
+/*
+ * This is the program to `cat' a file.
+ */
+char *catproc = "/bin/cat";
+
 /*
  * mhl runs this program as a visual-end.
  */
@@ -155,8 +161,8 @@ char *incproc = nmhbindir (/inc);
 char *installproc = nmhlibdir (/install-mh);
 
 /*
- * This is the program invoked by a "list" response to "What now?"
- *  whereas, showproc is the program invoked by show, next, prev.
+ * This is the default program invoked by a "list" response
+ * at the "What now?" prompt.
  */
 
 char *lproc = DEFAULT_PAGER;
@@ -179,6 +185,12 @@ char *moreproc = DEFAULT_PAGER;
 
 char *mhlproc = nmhlibdir (/mhl);
 
+/*
+ * This is the path to the program to display MIME messages.
+ */
+
+char *mhnproc = nmhbindir (/mhn);
+
 /* 
  * This is the super handy BBoard reading program, which is
  * really just the nmh shell program.
@@ -231,8 +243,8 @@ char *rmmproc = NULL;
 char *sendproc = nmhbindir (/send);
 
 /*
- * This program is called to list messages by the show program.
- * By setting showproc to mhl, the user can run mhl instead.
+ * This is the default program called to list messages by the show
+ * command.  By setting showproc to mhl, the user can run mhl instead.
  */
 
 char *showproc = DEFAULT_PAGER;
