@@ -5,9 +5,6 @@
  * $Id$
  */
 
-/*  Use built-in ftp client in mhn */
-#define FTP 1
-
 #define	VRSN_FIELD	"MIME-Version"
 #define	VRSN_VALUE	"1.0"
 #define	XXX_FIELD_PRF	"Content-"
