@@ -3,7 +3,7 @@
  * getanswer.c -- get a yes/no answer from the user
  */
 
-#include "../h/mh.h"
+#include <h/mh.h>
 #include <stdio.h>
 
 
