@@ -141,13 +141,19 @@ static unsigned char *locc(int, unsigned char *, unsigned char);
 
 static unsigned char **pat_map;
 
-extern int msg_count;	/* defined in sbr/m_msgdef.c = 0
-			 * disgusting hack for "inc" so it can 
-			 * know how many characters were stuffed
-			 * in the buffer on the last call (see
-			 * comments in uip/scansbr.c) */
+/*
+ * defined in sbr/m_msgdef.c = 0
+ * This is a disgusting hack for "inc" so it can know how many
+ * characters were stuffed in the buffer on the last call
+ * (see comments in uip/scansbr.c).
+ */
+extern int msg_count;
+
+/*
+ * defined in sbr/m_msgdef.c = MS_DEFAULT
+ */
+extern int msg_style;
 
-extern int msg_style;	/* defined in sbr/m_msgdef.c = MS_DEFAULT */
 /*
  * The "full" delimiter string for a packed maildrop consists
  * of a newline followed by the actual delimiter.  E.g., the
@@ -527,7 +533,7 @@ m_unknown(FILE *iob)
 #endif /* RPATHS */
     } else {
 	/* not a Unix style maildrop */
-	fseek (iob, pos, 0);
+	fseek (iob, pos, SEEK_SET);
 	if (mmdlm2 == NULL || *mmdlm2 == 0)
 	    mmdlm2 = "\001\001\001\001\n";
 	delimstr = mmdlm2;
@@ -607,9 +613,9 @@ m_Eom (int c, FILE *iob)
 	    return 1;
 
 #ifdef notdef
-	fseek (iob, pos, 0);
+	fseek (iob, pos, SEEK_SET);
 #else
-	fseek (iob, (long)(pos-1), 0);
+	fseek (iob, (long)(pos-1), SEEK_SET);
 	getc (iob);		/* should be OK */
 #endif /* !notdef */
 	return 0;
