@@ -5,7 +5,7 @@
  * $Id$
  */
 
-#include "../h/mh.h"
+#include <h/mh.h>
 
 #define	CWD	"./"
 #define	NCWD	(sizeof CWD - 1)
