@@ -1,6 +1,7 @@
 
 /*
- * refile.c -- refile the draft into another folder
+ * refile.c -- call the "fileproc" to refile the
+ *          -- draft into another folder
  *
  * $Id$
  */
@@ -22,9 +23,10 @@ refile (char **arg, char *file)
     vec[vecp++] = "-file";
     vec[vecp++] = file;
 
-    if (arg)
+    if (arg) {
 	while (*arg)
 	    vec[vecp++] = *arg++;
+    }
     vec[vecp] = NULL;
 
     m_update();		/* update the context file */
