@@ -126,7 +126,7 @@ main (int argc, char **argv)
 	adios (maildir, "unable to change directory to");
 
     /* read folder and create message structure */
-    if (!(mp = m_gmsg (folder)))
+    if (!(mp = m_readfolder (folder)))
 	adios (NULL, "unable to read folder %s", folder);
 
     if (mp->hghmsg == 0)
@@ -139,15 +139,16 @@ main (int argc, char **argv)
 
     make_comp (&comp);
 
+    /* annotate all the SELECTED messages */
     for (msgnum = mp->lowsel; msgnum <= mp->hghsel; msgnum++)
 	if (is_selected(mp, msgnum))
 	    annotate (m_name (msgnum), comp, text, inplace, datesw);
 
     m_replace (pfolder, folder);	/* update current folder */
     if (mp->lowsel != mp->curmsg)
-	m_setcur (mp, mp->lowsel);
-    m_sync (mp);	/* synchronize message sequences */
-    m_fmsg (mp);	/* free folder/message structure */
+	seq_setcur (mp, mp->lowsel);
+    seq_save (mp);	/* synchronize message sequences */
+    m_freefolder (mp);	/* free folder/message structure */
     m_update ();	/* update the context file       */
     done (0);
 }
