@@ -25,7 +25,7 @@ static struct swit switches[] = {
     { "normalize", 0 },
 #define	NNORMSW	3
     { "nonormalize", 0 },
-#define	WIDSW	4
+#define	WIDTHSW	4
     { "width columns", 0 },
 #define VERSIONSW 5
     { "version", 0 },
@@ -100,7 +100,7 @@ main (int argc, char **argv)
 		    form = NULL;
 		    continue;
 
-		case WIDSW: 
+		case WIDTHSW: 
 		    if (!(cp = *argp++) || *cp == '-')
 			adios (NULL, "missing argument to %s", argp[-2]);
 		    width = atoi (cp);
@@ -133,8 +133,12 @@ main (int argc, char **argv)
 	width = WBUFSIZ;
     fmt_norm = normalize;
     fmt_compile (nfs, &fmt);
-    dat[0] = dat[1] = dat[2] = dat[4] = 0;
+
+    dat[0] = 0;
+    dat[1] = 0;
+    dat[2] = 0;
     dat[3] = width;
+    dat[4] = 0;
 
     for (addrp = 0; addrs[addrp]; addrp++)
 	status += process (addrs[addrp], width, normalize);
