@@ -29,8 +29,6 @@ static struct swit switches[] = {
 
 static char delim3[] = "-------";
 
-static struct msgs *mp;
-
 struct smsg {
     long s_start;
     long s_stop;
@@ -39,17 +37,19 @@ struct smsg {
 /*
  * static prototypes
  */
-static void burst (struct smsg *, int, int, int, int);
+static int find_delim (int, struct smsg *);
+static void burst (struct msgs **, int, struct smsg *, int, int, int);
 static void cpybrst (FILE *, FILE *, char *, char *, int);
 
 
 main (int argc, char **argv)
 {
     int inplace = 0, quietsw = 0, verbosw = 0;
-    int msgp = 0, hi, msgnum;
+    int msgp = 0, hi, msgnum, numburst;
     char *cp, *maildir, *folder = NULL, buf[100], **ap;
     char **argp, *arguments[MAXARGS], *msgs[MAXARGS];
     struct smsg *smsgs;
+    struct msgs *mp;
 
 #ifdef LOCALE
     setlocale(LC_ALL, "");
@@ -67,40 +67,40 @@ main (int argc, char **argv)
     while ((cp = *argp++)) {
 	if (*cp == '-')
 	    switch (smatch (++cp, switches)) {
-		case AMBIGSW: 
-		    ambigsw (cp, switches);
-		    done (1);
-		case UNKWNSW: 
-		    adios (NULL, "-%s unknown\n", cp);
+	    case AMBIGSW: 
+		ambigsw (cp, switches);
+		done (1);
+	    case UNKWNSW: 
+		adios (NULL, "-%s unknown\n", cp);
 
-		case HELPSW: 
-		    sprintf (buf, "%s [+folder] [msgs] [switches]", invo_name);
-		    print_help (buf, switches);
-		    done (1);
-		case VERSIONSW:
-		    print_version(invo_name);
-		    done (1);
+	    case HELPSW: 
+		sprintf (buf, "%s [+folder] [msgs] [switches]", invo_name);
+		print_help (buf, switches);
+		done (1);
+	    case VERSIONSW:
+		print_version(invo_name);
+		done (1);
 
-		case INPLSW: 
-		    inplace++;
-		    continue;
-		case NINPLSW: 
-		    inplace = 0;
-		    continue;
+	    case INPLSW: 
+		inplace++;
+		continue;
+	    case NINPLSW: 
+		inplace = 0;
+		continue;
 
-		case QIETSW: 
-		    quietsw++;
-		    continue;
-		case NQIETSW: 
-		    quietsw = 0;
-		    continue;
+	    case QIETSW: 
+		quietsw++;
+		continue;
+	    case NQIETSW: 
+		quietsw = 0;
+		continue;
 
-		case VERBSW: 
-		    verbosw++;
-		    continue;
-		case NVERBSW: 
-		    verbosw = 0;
-		    continue;
+	    case VERBSW: 
+		verbosw++;
+		continue;
+	    case NVERBSW: 
+		verbosw = 0;
+		continue;
 	    }
 	if (*cp == '+' || *cp == '@') {
 	    if (folder)
@@ -124,7 +124,7 @@ main (int argc, char **argv)
 	adios (maildir, "unable to change directory to");
 
     /* read folder and create message structure */
-    if (!(mp = m_gmsg (folder)))
+    if (!(mp = m_readfolder (folder)))
 	adios (NULL, "unable to read folder %s", folder);
 
     if (mp->hghmsg == 0)
@@ -134,79 +134,100 @@ main (int argc, char **argv)
     for (msgnum = 0; msgnum < msgp; msgnum++)
 	if (!m_convert (mp, msgs[msgnum]))
 	    done (1);
-    m_setseq (mp);	/* set the previous-sequence */
+    seq_setprev (mp);	/* set the previous-sequence */
 
     smsgs = (struct smsg *)
-		calloc ((size_t) (MAXFOLDER + 2), sizeof *smsgs);
+	calloc ((size_t) (MAXFOLDER + 2), sizeof(*smsgs));
     if (smsgs == NULL)
 	adios (NULL, "unable to allocate burst storage");
 
     hi = mp->hghmsg + 1;
 
     /* burst all the SELECTED messages */
-    for (msgnum = mp->lowsel; msgnum <= mp->hghsel; msgnum++)
-	if (is_selected (mp, msgnum))
-	    burst (smsgs, msgnum, inplace, quietsw, verbosw);
+    for (msgnum = mp->lowsel; msgnum <= mp->hghsel; msgnum++) {
+	if (is_selected (mp, msgnum)) {
+	    if ((numburst = find_delim (msgnum, smsgs)) >= 1) {
+		if (verbosw)
+		    printf ("%d message%s exploded from digest %d\n",
+			    numburst, numburst > 1 ? "s" : "", msgnum);
+		burst (&mp, msgnum, smsgs, numburst, inplace, verbosw);
+	    } else {
+		if (numburst == 0)
+		    if (!quietsw)
+			admonish (NULL, "message %d not in digest format", msgnum);
+		else
+		    adios (NULL, "burst() botch -- you lose big");
+	    }
+	}
+    }
 
     free ((char *) smsgs);
 
     m_replace (pfolder, folder);	/* update current folder */
+
+    /*
+     * If -inplace is given, then the first message burst becomes
+     * the current message (which will now show a table of contents).
+     * Otherwise, the first message extracted from the first digest
+     * becomes the current message.
+     */
     if (inplace) {
 	if (mp->lowsel != mp->curmsg)
-	    m_setcur (mp, mp->lowsel);
+	    seq_setcur (mp, mp->lowsel);
     } else {
 	if (hi <= mp->hghmsg)
-	    m_setcur (mp, hi);
+	    seq_setcur (mp, hi);
     }
 
-    m_sync (mp);	/* synchronize message sequences */
-    m_fmsg (mp);	/* free folder/message structure */
+    seq_save (mp);	/* synchronize message sequences */
+    m_freefolder (mp);	/* free folder/message structure */
     m_update ();	/* update the context file       */
     done (0);
 }
 
-static void
-burst (struct smsg *smsgs, int msgnum, int inplace, int quietsw, int verbosw)
+
+/*
+ * Scan the message and find the beginning and
+ * end of all the messages in the digest.
+ */
+
+static int
+find_delim (int msgnum, struct smsg *smsgs)
 {
-    int i, j, ld3, wasdlm, mode, msgp;
-    register long pos;
-    register char c, *msgnam;
+    int ld3, wasdlm, msgp;
+    long pos;
+    char c, *msgnam;
     int cc;
-    char buffer[BUFSIZ], f1[BUFSIZ], f2[BUFSIZ], f3[BUFSIZ];
-    struct stat st;
-    register FILE *in, *out;
+    char buffer[BUFSIZ];
+    FILE *in;
 
     ld3 = strlen (delim3);
 
     if ((in = fopen (msgnam = m_name (msgnum), "r")) == NULL)
 	adios (msgnam, "unable to read message");
 
-    mode = fstat (fileno (in), &st) != NOTOK ? (st.st_mode & 0777)
-	: m_gmprot ();
     for (msgp = 0, pos = 0L; msgp <= MAXFOLDER;) {
-	while (fgets (buffer, sizeof buffer, in) != NULL
-		&& buffer[0] == '\n')
+	while (fgets (buffer, sizeof(buffer), in) != NULL && buffer[0] == '\n')
 	    pos += (long) strlen (buffer);
 	if (feof (in))
 	    break;
-	fseek (in, pos, 0);
+	fseek (in, pos, SEEK_SET);
 	smsgs[msgp].s_start = pos;
 
-	for (c = 0;
-		fgets (buffer, sizeof buffer, in) != NULL;
-		c = buffer[0])
+	for (c = 0; fgets (buffer, sizeof(buffer), in) != NULL; c = buffer[0]) {
 	    if (strncmp (buffer, delim3, ld3) == 0
 		    && (msgp == 1 || c == '\n')
 		    && ((cc = peekc (in)) == '\n' || cc == EOF))
 		break;
 	    else
 		pos += (long) strlen (buffer);
+	}
 
 	wasdlm = strncmp (buffer, delim3, ld3) == 0;
 	if (smsgs[msgp].s_start != pos)
 	    smsgs[msgp++].s_stop = (c == '\n' && wasdlm) ? pos - 1 : pos;
 	if (feof (in)) {
-#ifdef	notdef
+#if 0
 	    if (wasdlm) {
 		smsgs[msgp - 1].s_stop -= ((long) strlen (buffer) + 1);
 		msgp++;		/* fake "End of XXX Digest" */
@@ -217,34 +238,54 @@ burst (struct smsg *smsgs, int msgnum, int inplace, int quietsw, int verbosw)
 	pos += (long) strlen (buffer);
     }
 
-    switch (msgp--) {		/* toss "End of XXX Digest" */
-	case 0: 
-	    adios (NULL, "burst() botch -- you lose big");
+    fclose (in);
+    return (msgp - 1);		/* toss "End of XXX Digest" */
+}
 
-	case 1: 
-	    if (!quietsw)
-		admonish (NULL, "message %d not in digest format", msgnum);
-	    fclose (in);
-	    return;
 
-	default: 
-	    if (verbosw)
-		printf ("%d message%s exploded from digest %d\n",
-			msgp, msgp != 1 ? "s" : "", msgnum);
-	    break;
-    }
-    /* msgp now contains the number of new msgs to be created */
+/*
+ * Burst out all the messages in the digest
+ */
 
-    if ((mp = m_remsg (mp, 0, mp->hghmsg + msgp)) == NULL)
+static void
+burst (struct msgs **mpp, int msgnum, struct smsg *smsgs, int numburst,
+	int inplace, int verbosw)
+{
+    int i, j, mode;
+    char *msgnam;
+    char f1[BUFSIZ], f2[BUFSIZ], f3[BUFSIZ];
+    FILE *in, *out;
+    struct stat st;
+    struct msgs *mp;
+
+    if ((in = fopen (msgnam = m_name (msgnum), "r")) == NULL)
+	adios (msgnam, "unable to read message");
+
+    mode = fstat (fileno(in), &st) != NOTOK ? (st.st_mode & 0777) : m_gmprot();
+
+    mp = *mpp;
+    if ((mp = m_remsg (mp, 0, mp->hghmsg + numburst)) == NULL)
 	adios (NULL, "unable to allocate folder storage");
+    *mpp = mp;
 
     j = mp->hghmsg;		/* old value */
-    mp->hghmsg += msgp;
-    mp->nummsg += msgp;
-    if (mp->hghsel > msgnum)
-	mp->hghsel += msgp;
+    mp->hghmsg += numburst;
+    mp->nummsg += numburst;
 
-    if (inplace)
+    /*
+     * If this is not the highest SELECTED message, then
+     * increment mp->hghsel by numburst, since the highest
+     * SELECTED is about to be slid down by that amount.
+     */
+    if (msgnum < mp->hghsel)
+	mp->hghsel += numburst;
+
+    /*
+     * If -inplace is given, renumber the messages after the
+     * source message, to make room for each of the messages
+     * contained within the digest.
+     */
+    if (inplace) {
 	for (i = mp->hghmsg; j > msgnum; i--, j--) {
 	    strcpy (f1, m_name (i));
 	    strcpy (f2, m_name (j));
@@ -259,10 +300,13 @@ burst (struct smsg *smsgs, int msgnum, int inplace, int quietsw, int verbosw)
 		mp->msgflags |= SEQMOD;
 	    }
 	}
+    }
     
     unset_selected (mp, msgnum);
-    i = inplace ? msgnum + msgp : mp->hghmsg; /* new hghmsg is hghmsg+msgp */
-    for (j = msgp; j >= (inplace ? 0 : 1); i--, j--) {
+
+    /* new hghmsg is hghmsg + numburst */
+    i = inplace ? msgnum + numburst : mp->hghmsg;
+    for (j = numburst; j >= (inplace ? 0 : 1); i--, j--) {
 	strcpy (f1, m_name (i));
 	strcpy (f2, m_scratch ("", invo_name));
 	if (verbosw && i != msgnum)
@@ -272,7 +316,7 @@ burst (struct smsg *smsgs, int msgnum, int inplace, int quietsw, int verbosw)
 	if ((out = fopen (f2, "w")) == NULL)
 	    adios (f2, "unable to write message");
 	chmod (f2, mode);
-	fseek (in, pos = smsgs[j].s_start, 0);
+	fseek (in, smsgs[j].s_start, SEEK_SET);
 	cpybrst (in, out, msgnam, f2,
 		(int) (smsgs[j].s_stop - smsgs[j].s_start));
 	fclose (out);
