@@ -6,6 +6,7 @@
  */
 
 #include <h/mh.h>
+#include <fcntl.h>
 
 static struct swit switches[] = {
 #define	DFOLDSW                0
@@ -196,7 +197,7 @@ main (int argc, char **argv)
 	    adios (maildir, "unable to change directory to");
 
 	/* read folder and create message structure */
-	if (!(mp = m_gmsg (folder)))
+	if (!(mp = m_readfolder (folder)))
 	    adios (NULL, "unable to read folder %s", folder);
 
 	if (mp->hghmsg == 0)
@@ -205,19 +206,19 @@ main (int argc, char **argv)
 	/* parse the message range/sequence/name and set SELECTED */
 	if (!m_convert (mp, msg))
 	    done (1);
-	m_setseq (mp);	/* set the previous-sequence */
+	seq_setprev (mp);	/* set the previous-sequence */
 
 	if (mp->numsel > 1)
 	    adios (NULL, "only one message at a time!");
 
-	if ((in = open (form = getcpy (m_name (mp->lowsel)), 0)) == NOTOK)
+	if ((in = open (form = getcpy (m_name (mp->lowsel)), O_RDONLY)) == NOTOK)
 	    adios (form, "unable to open message");
     } else {
 	if (form) {
-	    if ((in = open (etcpath (form), 0)) == NOTOK)
+	    if ((in = open (etcpath (form), O_RDONLY)) == NOTOK)
 		adios (form, "unable to open form file");
 	} else {
-	    if ((in = open (etcpath (components), 0)) == NOTOK)
+	    if ((in = open (etcpath (components), O_RDONLY)) == NOTOK)
 		adios (components, "unable to open default components file");
 	    form = components;
 	}
@@ -225,7 +226,7 @@ main (int argc, char **argv)
 
 try_it_again: ;
     strcpy (drft, m_draft (dfolder, file, use, &isdf));
-    if ((out = open (drft, 0)) != NOTOK) {
+    if ((out = open (drft, O_RDONLY)) != NOTOK) {
 	i = fdcompare (in, out);
 	close (out);
 	if (use || i)
