@@ -21,7 +21,7 @@ static struct swit switches[] = {
     { "form formatfile", 0 },
 #define	FMTSW                 1
     { "format string", 5 },
-#define	WIDSW                 2
+#define	WIDTHSW               2
     { "width columns", 0 },
 #define VERSIONSW             3
     { "version", 0 },
@@ -93,7 +93,7 @@ main (int argc, char **argv)
 		    form = NULL;
 		    continue;
 
-		case WIDSW: 
+		case WIDTHSW: 
 		    if (!(cp = *argp++) || *cp == '-')
 			adios (NULL, "missing argument to %s", argp[-2]);
 		    width = atoi (cp);
@@ -118,8 +118,12 @@ main (int argc, char **argv)
     if (width > WBUFSIZ)
 	width = WBUFSIZ;
     fmt_compile (nfs, &fmt);
-    dat[0] = dat[1] = dat[2] = dat[4] = 0;
+
+    dat[0] = 0;
+    dat[1] = 0;
+    dat[2] = 0;
     dat[3] = width;
+    dat[4] = 0;
 
     for (datep = 0; dates[datep]; datep++)
 	status += process (dates[datep], width);
