@@ -1,5 +1,6 @@
 /*
- * flist.c -- list nmh folders containg messages in a given sequence
+ * flist.c -- list nmh folders containing messages
+ *         -- in a given sequence
  *
  * originally by
  * David Nichols, Xerox-PARC, November, 1992
@@ -171,7 +172,7 @@ main(int argc, char **argv)
      * for the `unseen' sequence.
      */
     if (!sequence)
-	sequence = m_find("Unseen-Sequence");
+	sequence = m_find(usequence);
 
     GetFolderOrder();
     ScanMailDir();
@@ -306,7 +307,7 @@ BuildFolderList(char *dirName)
 void
 AddFolder(char *name, int force)
 {
-    int i, flags, nSeq;
+    int msgnum, seqnum, nSeq;
     struct Folder *f;
     struct msgs *mp;
 
@@ -328,33 +329,23 @@ AddFolder(char *name, int force)
     }
 #endif
 
-    nSeq = 0;
-
     /* read folder and create message structure */
-    if (!(mp = m_gmsg(name))) {
+    if (!(mp = m_readfolder (name))) {
 	advise(NULL, "Can't read folder %s.", name);
 	return;
     }
 
-    /*
-     * Get the bit flag corresponding to the
-     * sequence we want to search for.
-     */
-    if (sequence)
-	flags = m_seqflag(mp, sequence);
-    else
-	flags = 0;
+    nSeq = 0;
 
-    if (flags) {
-	for (i = mp->lowmsg; i <= mp->hghmsg; i++) {
-	    if (mp->msgstats[i] & flags)
+    /* Count the number of messages in the sequence */
+    if (sequence && ((seqnum = seq_getnum(mp, sequence)) != -1)) {
+	for (msgnum = mp->lowmsg; msgnum <= mp->hghmsg; msgnum++) {
+	    if (in_sequence(mp, seqnum, msgnum))
 		nSeq++;
 	}
     }
 
-    /*
-     * Save folder/message information in Folder struct.
-     */
+    /* Save folder/message information in Folder struct */
     if (nSeq > 0 || force) {
 	AllocFolders(&folders, &nFoldersAlloced, nFolders + 1);
 	f = &folders[nFolders++];
@@ -364,7 +355,7 @@ AddFolder(char *name, int force)
 	f->priority = AssignPriority(f->name);
     }
 
-    m_fmsg (mp);	/* free folder/message structure */
+    m_freefolder (mp);	/* free folder/message structure */
 }
 
 void
