@@ -113,7 +113,6 @@ static void addir (char *);
 static void addfold (char *);
 static int compare (char *, char *);
 static void do_readonly (void);
-static struct msgs *pack_folder (struct msgs *);
 
 
 main (int argc, char **argv)
@@ -429,7 +428,7 @@ get_folder_info (char *fold, char *msg)
 	    /*
 	     * create message structure and get folder info
 	     */
-	    if (!(mp = m_gmsg (fold))) {
+	    if (!(mp = m_readfolder (fold))) {
 		admonish (NULL, "unable to read folder %s", fold);
 		return 0;
 	    }
@@ -437,8 +436,11 @@ get_folder_info (char *fold, char *msg)
 	    if (msg && !sfold (mp, msg))
 		retval = 0;
 
-	    if (fpack)
-		mp = pack_folder (mp);
+	    if (fpack) {
+		mp = m_packfolder (mp, fverb);
+		seq_save (mp);	/* synchronize the sequences */
+		m_update ();	/* update the context file   */
+	    }
 
 	    if (!fshort) {
 		total_folders++;
@@ -451,8 +453,8 @@ get_folder_info (char *fold, char *msg)
 		fi.others = other_files (mp);
 	    }
 
-	    /* free message structure */
-	    m_fmsg (mp);
+	    /* free folder/message structure */
+	    m_freefolder (mp);
 	}
     } else {
 	fi.error = 1;
@@ -546,58 +548,14 @@ sfold (struct msgs *mp, char *msg)
 	admonish (NULL, "only one message at a time!");
 	return 0;
     }
-    m_setseq (mp);		/* set the previous-sequence     */
-    m_setcur (mp, mp->lowsel);	/* set current message           */
-    m_sync (mp);		/* synchronize message sequences */
+    seq_setprev (mp);		/* set the previous-sequence     */
+    seq_setcur (mp, mp->lowsel);/* set current message           */
+    seq_save (mp);		/* synchronize message sequences */
     m_update ();		/* update the context file       */
 
     return 1;
 }
 
-/*
- * Pack the folder
- */
-
-static struct msgs *
-pack_folder (struct msgs *mp)
-{
-    register int hole, msgnum;
-    char newmsg[BUFSIZ], oldmsg[BUFSIZ];
-
-    if (mp->lowmsg > 1 && (mp = m_remsg (mp, 1, mp->hghmsg)) == NULL)
-	adios (NULL, "unable to allocate folder storage");
-
-    for (msgnum = mp->lowmsg, hole = 1; msgnum <= mp->hghmsg; msgnum++) {
-	if (does_exist (mp, msgnum)) {
-	    if (msgnum != hole) {
-		strcpy (newmsg, m_name (hole));
-		strcpy (oldmsg, m_name (msgnum));
-		if (fverb)
-		    printf ("message %s becomes %s\n", oldmsg, newmsg);
-		if (rename (oldmsg, newmsg) == NOTOK)
-		    adios (newmsg, "unable to rename %s to", oldmsg);
-		if (msgnum == mp->curmsg)
-		    m_setcur (mp, mp->curmsg = hole);
-		mp->msgstats[hole] = mp->msgstats[msgnum];
-		mp->msgflags |= SEQMOD;
-		if (msgnum == mp->lowsel)
-		    mp->lowsel = hole;
-		if (msgnum == mp->hghsel)
-		    mp->hghsel = hole;
-	    }
-	    hole++;
-	}
-    }
-    if (mp->nummsg > 0) {
-	mp->lowmsg = 1;
-	mp->hghmsg = hole - 1;
-    }
-    m_sync (mp);
-    m_update ();	/* update the context file */
-
-    return mp;
-}
-
 
 static void
 addir (char *name)
