@@ -6,6 +6,7 @@
  */
 
 #include <h/mh.h>
+#include <fcntl.h>
 #include <h/fmt_scan.h>
 #include <zotnet/tws/tws.h>
 
@@ -345,7 +346,7 @@ try_it_again: ;
 
     if (chdir (maildir) == NOTOK)
 	adios (maildir, "unable to change directory to");
-    if (!(mp = m_gmsg (folder)))
+    if (!(mp = m_readfolder (folder)))
 	adios (NULL, "unable to read folder %s", folder);
     if (mp->hghmsg == 0)
 	adios (NULL, "no messages in %s", folder);
@@ -354,7 +355,7 @@ try_it_again: ;
     for (msgnum = 0; msgnum < msgp; msgnum++)
 	if (!m_convert (mp, msgs[msgnum]))
 	    done (1);
-    m_setseq (mp);	/* set the previous sequence */
+    seq_setprev (mp);	/* set the previous sequence */
 
 go_to_it: ;
     if (filter && access (filter, R_OK) == NOTOK)
@@ -379,11 +380,11 @@ go_to_it: ;
     }
     else
 	if (form) {
-	    if ((in = open (etcpath (form), 0)) == NOTOK)
+	    if ((in = open (etcpath (form), O_RDONLY)) == NOTOK)
 		adios (form, "unable to open form file");
 	}
 	else {
-	    if ((in = open (etcpath (forwcomps), 0)) == NOTOK)
+	    if ((in = open (etcpath (forwcomps), O_RDONLY)) == NOTOK)
 		adios (forwcomps, "unable to open default components file");
 	    form = forwcomps;
 	}
@@ -395,7 +396,7 @@ go_to_it: ;
     close (in);
 
     if (file) {
-	if ((in = open (file, 0)) == NOTOK)
+	if ((in = open (file, O_RDONLY)) == NOTOK)
 	    adios (file, "unable to open");
 	cpydata (in, out, file, drft);
 	close (in);
@@ -420,8 +421,8 @@ go_to_it: ;
 
     m_replace (pfolder, folder);	/* update current folder   */
     if (mp->lowsel != mp->curmsg)
-	m_setcur (mp, mp->lowsel);
-    m_sync (mp);
+	seq_setcur (mp, mp->lowsel);
+    seq_save (mp);
     m_update ();			/* update the context file */
 
 edit_it: ;
@@ -534,7 +535,7 @@ copy_draft (int out, char *digest, char *file, int volume, int issue, int mime)
 	    }
 	    write (out, buffer, strlen (buffer));
 
-	    if ((fd = open (msgnam = m_name (msgnum), 0)) == NOTOK) {
+	    if ((fd = open (msgnam = m_name (msgnum), O_RDONLY)) == NOTOK) {
 		admonish (msgnam, "unable to read message");
 		continue;
 	    }
@@ -585,7 +586,7 @@ build_form (char *form, char *digest, int volume, int issue)
 	cptr->c_text = digest;
     FINDCOMP (cptr, "date");
     if (cptr)
-	cptr->c_text = getcpy(dtimenow ());
+	cptr->c_text = getcpy(dtimenow (0));
 
     dat[0] = issue;
     dat[1] = volume;
