@@ -18,6 +18,7 @@
 #endif
 
 #include <h/mh.h>
+#include <fcntl.h>
 
 #ifdef POP
 # include <h/dropsbr.h>
@@ -117,7 +118,7 @@ static struct swit switches[] = {
     { "uucp", MFminc (-4) },
 #define	NUUCPSW                   22
     { "nouucp", MFminc (-6) },
-#define	WIDSW                     23
+#define	WIDTHSW                   23
     { "width columns", 0 },
 #define VERSIONSW                 24
     { "version", 0 },
@@ -132,7 +133,7 @@ extern int errno;
 int snoop = 0;
 extern char response[];
 
-static char *file = NULL;
+static char *packfile = NULL;
 static int size;
 static long pos;
 static long start;
@@ -173,10 +174,11 @@ main (int argc, char **argv)
     int chgflag = 1, trnflag = 1, decflag = 1;
     int noisy = 1, width = 0, locked = 0;
     int rpop = 0, i, hghnum, msgnum;
-    char *cp, *maildir, *folder = NULL, *form = NULL;
-    char *format = NULL, *audfile = NULL, *from = NULL;
-    char *host = NULL;
-    char *newmail, buf[100], **ap;
+    char *cp, *maildir, *folder = NULL;
+    char *format = NULL, *form = NULL;
+    char *newmail, *host = NULL;
+    char *audfile = NULL, *from = NULL;
+    char buf[100], **ap;
     char **argp, *nfs, *arguments[MAXARGS];
     char *user = NULL;
     struct msgs *mp;
@@ -208,7 +210,7 @@ main (int argc, char **argv)
     mts_init (invo_name);
 
 #ifdef POP
-#ifdef HESIOD
+# ifdef HESIOD
     /*
      * Scheme is:
      *        use MAILHOST environment variable if present,
@@ -221,13 +223,17 @@ main (int argc, char **argv)
     else if ((po = hes_getmailhost(getusr())) != NULL &&
 	    strcmp(po->po_type, "POP") == 0)
 	pophost = po->po_host;
-#endif /* HESIOD */
+# endif /* HESIOD */
+    /*
+     * If there is a valid "pophost" entry in mts.conf,
+     * then use it as the default host.
+     */
     if (pophost && *pophost)
 	host = pophost;
 
     if ((cp = getenv ("MHPOPDEBUG")) && *cp)
 	snoop++;
-#endif
+#endif /* POP */
 
     if ((cp = m_find (invo_name)) != NULL) {
 	ap = brkstring (cp = getcpy (cp), " ", "\n");
@@ -274,12 +280,15 @@ main (int argc, char **argv)
 		case TRNCSW: 
 		    trnflag++;
 		    continue;
+		case NTRNCSW: 
+		    trnflag = 0;
+		    continue;
+
 		case MSW: 
 		    if (!(cp = *argp++) || *cp == '-')
 			adios (NULL, "missing argument to %s", argp[-2]);
-		    from = path (cp, TFILE);/* fall */
-		case NTRNCSW: 
-		    trnflag = 0;
+		    from = path (cp, TFILE);
+		    trnflag = 0;	/* don't truncate */
 		    continue;
 
 		case SILSW: 
@@ -300,7 +309,7 @@ main (int argc, char **argv)
 		    form = NULL;
 		    continue;
 
-		case WIDSW: 
+		case WIDTHSW: 
 		    if (!(cp = *argp++) || *cp == '-')
 			adios (NULL, "missing argument to %s", argp[-2]);
 		    width = atoi (cp);
@@ -337,13 +346,13 @@ main (int argc, char **argv)
 		    if (!(cp = *argp++) || *cp == '-')
 			adios (NULL, "missing argument to %s", argp[-2]);
 #else /* POP */
-		    if (!(file = *argp++) || *file == '-')
+		    if (!(packfile = *argp++) || *packfile == '-')
 			adios (NULL, "missing argument to %s", argp[-2]);
 #endif /* POP */
 		    continue;
 		case NPACKSW:
 #ifdef POP
-		    file = NULL;
+		    packfile = NULL;
 #endif /* POP */
 		    continue;
 		case APOPSW:
@@ -362,9 +371,9 @@ main (int argc, char **argv)
 		adios (NULL, "only one folder at a time!");
 	    else
 		folder = path (cp + 1, *cp == '+' ? TFOLDER : TSUBCWF);
-	}
-	else
+	} else {
 	    adios (NULL, "usage: %s [+folder] [switches]", invo_name);
+	}
     }
 
 #ifdef MAILGROUP
@@ -378,6 +387,11 @@ main (int argc, char **argv)
     if (from || !host || rpop <= 0)
 	setuid (getuid ());
 #endif /* POP */
+
+    /*
+     * Are we getting the mail from an
+     * alternate file?
+     */
     if (from) {
 	newmail = from;
 #ifdef POP
@@ -387,6 +401,10 @@ main (int argc, char **argv)
 	    adios (NULL, "no mail to incorporate");
     }
 #ifdef POP
+    /*
+     * Are we getting the mail from
+     * a POP server?
+     */
     else if (host) {
 	if (user == NULL)
 	    user = getusr ();
@@ -395,13 +413,21 @@ main (int argc, char **argv)
 	else
 	    ruserpass (host, &user, &pass);
 
-#if defined(RPOP) || defined(APOP)
-	if (pop_init (host, user, pass, snoop, rpop) == NOTOK
-#else
-	if (pop_init (host, user, pass, snoop) == NOTOK
-#endif
-		|| pop_stat (&nmsgs, &nbytes) == NOTOK)
+	/*
+	 * initialize POP connection
+	 */
+# if defined(RPOP) || defined(APOP)
+	if (pop_init (host, user, pass, snoop, rpop) == NOTOK)
 	    adios (NULL, "%s", response);
+# else
+	if (pop_init (host, user, pass, snoop) == NOTOK)
+	    adios (NULL, "%s", response);
+# endif
+
+	/* Check if there are any messages */
+	if (pop_stat (&nmsgs, &nbytes) == NOTOK)
+	    adios (NULL, "%s", response);
+
 	if (rpop > 0)
 	    setuid (getuid ());
 	if (nmsgs == 0) {
@@ -410,6 +436,9 @@ main (int argc, char **argv)
 	}
     }
 #endif /* POP */
+    /*
+     * we will get the mail from the standard maildrop
+     */
     else {
 	if (((newmail = getenv ("MAILDROP")) && *newmail)
 		|| ((newmail = m_find ("maildrop")) && *newmail))
@@ -426,9 +455,10 @@ main (int argc, char **argv)
     }
 
 #ifdef POP
-    if (host && file)
-	goto go_to_it;
+    if (host && packfile)
+	goto go_to_it;		/* skip the folder setup */
 #endif /* POP */
+
     if (!m_find ("path"))
 	free (path ("./", TFOLDER));
     if (!folder && !(folder = m_find (inbox)))
@@ -450,13 +480,13 @@ main (int argc, char **argv)
 	adios (maildir, "unable to change directory to");
 
     /* read folder and create message structure */
-    if (!(mp = m_gmsg (folder)))
+    if (!(mp = m_readfolder (folder)))
 	adios (NULL, "unable to read folder %s", folder);
 
 #ifdef POP
 go_to_it: ;
-    if (host == NULL)
-#endif	/* POP */
+    if (host == NULL) {
+#endif /* POP */
     if (access (newmail, W_OK) == NOTOK) {
 	trnflag = 0;
 	if ((in = fopen (newmail, "r")) == NULL)
@@ -473,13 +503,19 @@ go_to_it: ;
 #ifdef MAILGROUP
 	setgid(return_gid);	/* Reset gid to lock mail file */
 #endif /* MAILGROUP */
+
+	/* lock and fopen the mail spool */
 	if ((in = lkfopen (newmail, "r")) == NULL)
 	    adios (NULL, "unable to lock and fopen %s", newmail);
+
 #ifdef MAILGROUP
 	setgid(getgid());	/* Return us to normal privileges */
 #endif /* MAILGROUP */
 	fstat (fileno(in), &s1);
     }
+#ifdef POP
+    }			/* host == NULL */
+#endif /* POP */
 
 #ifdef MAILGROUP
 	setgid(getgid());	/* Return us to normal privileges */
@@ -495,12 +531,12 @@ go_to_it: ;
 		chmod (audfile, m_gmprot ());
 #ifndef	POP
 	fprintf (aud, from ? "<<inc>> %s  -ms %s\n" : "<<inc>> %s\n",
-		dtimenow (), from);
+		dtimenow (0), from);
 #else /* POP */
 	fprintf (aud, from ? "<<inc>> %s -ms %s\n"
 			: host ? "<<inc>> %s -host %s -user %s%s\n"
 			: "<<inc>> %s\n",
-		 dtimenow (), from ? from : host, user,
+		 dtimenow (0), from ? from : host, user,
 		 rpop < 0 ? " -apop" : rpop > 0 ? " -rpop" : "");
 #endif /* POP */
     }
@@ -526,25 +562,27 @@ go_to_it: ;
     }
 
 #ifdef POP
+    /*
+     * Get the mail from a POP server
+     */
     if (host) {
-	if (file) {
-	    file = path (file, TFILE);
-	    if (stat (file, &st) == NOTOK) {
+	if (packfile) {
+	    packfile = path (packfile, TFILE);
+	    if (stat (packfile, &st) == NOTOK) {
 		if (errno != ENOENT)
-		    adios (file, "error on file");
-		cp = concat ("Create file \"", file, "\"? ", NULL);
+		    adios (packfile, "error on file");
+		cp = concat ("Create file \"", packfile, "\"? ", NULL);
 		if (noisy && !getanswer (cp))
 		    done (1);
 		free (cp);
 	    }
 	    msgnum = map_count ();
-	    if ((pd = mbx_open (file, mbx_style, getuid (), getgid (), m_gmprot ()))
+	    if ((pd = mbx_open (packfile, mbx_style, getuid(), getgid(), m_gmprot()))
 		    == NOTOK)
-		adios (file, "unable to open");
+		adios (packfile, "unable to open");
 	    if ((pf = fdopen (pd, "w+")) == NULL)
-		adios (NULL, "unable to fdopen %s", file);
-	}
-	else {
+		adios (NULL, "unable to fdopen %s", packfile);
+	} else {
 	    hghnum = msgnum = mp->hghmsg;
 	    if ((mp = m_remsg (mp, 0, mp->hghmsg + nmsgs)) == NULL)
 		adios (NULL, "unable to allocate folder storage");
@@ -552,8 +590,8 @@ go_to_it: ;
 
 	for (i = 1; i <= nmsgs; i++) {
 	    msgnum++;
-	    if (file) {
-		fseek (pf, 0L, 1);
+	    if (packfile) {
+		fseek (pf, 0L, SEEK_CUR);
 		pos = ftell (pf);
 		size = 0;
 		fwrite (mmdlm1, 1, strlen (mmdlm1), pf);
@@ -562,11 +600,11 @@ go_to_it: ;
 		if (pop_retr (i, pop_pack) == NOTOK)
 		    adios (NULL, "%s", response);
 
-		fseek (pf, 0L, 1);
+		fseek (pf, 0L, SEEK_CUR);
 		stop = ftell (pf);
 		if (fflush (pf))
-		    adios (file, "write error on");
-		fseek (pf, start, 0);
+		    adios (packfile, "write error on");
+		fseek (pf, start, SEEK_SET);
 	    } else {
 		cp = getcpy (m_name (msgnum));
 		if ((pf = fopen (cp, "w+")) == NULL)
@@ -579,10 +617,10 @@ go_to_it: ;
 
 		if (fflush (pf))
 		    adios (cp, "write error on");
-		fseek (pf, 0L, 0);
+		fseek (pf, 0L, SEEK_SET);
 	    }
 	    switch (p = scan (pf, msgnum, 0, nfs, width,
-			file ? 0 : msgnum == mp->hghmsg + 1 && chgflag,
+			packfile ? 0 : msgnum == mp->hghmsg + 1 && chgflag,
 			1,	/* check UNSEEN? */
 			0, stop - start, noisy)) {
 		case SCNEOF: 
@@ -604,15 +642,15 @@ go_to_it: ;
 		default: 
 		    if (aud)
 			fputs (scanl, aud);
-#ifdef MHE
+# ifdef MHE
 		    if (mhe)
 			fputs (scanl, mhe);
-#endif /* MHE */
+# endif /* MHE */
 		    if (noisy)
 			fflush (stdout);
-		    if (!file) {
+		    if (!packfile) {
 			mp->msgstats[msgnum] = EXISTS;
-#ifdef TMA
+# ifdef TMA
 			if (p == SCNENC) {
 			    if (mp->lowsel == 0 || msgnum < mp->lowsel)
 				mp->lowsel = msgnum;
@@ -621,22 +659,22 @@ go_to_it: ;
 			    set_selected (mp, msgnum);
 			    mp->numsel++;
 			}
-#endif /* TMA */
+# endif /* TMA */
 			set_unseen (mp, msgnum);
 			mp->msgflags |= SEQMOD;
 		    }
 		    break;
 		}
-	    if (file) {
-		fseek (pf, stop, 0);
+	    if (packfile) {
+		fseek (pf, stop, SEEK_SET);
 		fwrite (mmdlm2, 1, strlen (mmdlm2), pf);
 		if (fflush (pf) || ferror (pf)) {
 		    int e = errno;
 		    pop_quit ();
 		    errno = e;
-		    adios (file, "write error on");
+		    adios (packfile, "write error on");
 		}
-		map_write (file, pd, 0, 0L, start, stop, pos, size, noisy);
+		map_write (packfile, pd, 0, 0L, start, stop, pos, size, noisy);
 	    } else {
 		if (ferror(pf) || fclose (pf)) {
 		    int e = errno;
@@ -653,14 +691,17 @@ go_to_it: ;
 	}
 	if (pop_quit () == NOTOK)
 	    adios (NULL, "%s", response);
-	if (file) {
-	    mbx_close (file, pd);
+	if (packfile) {
+	    mbx_close (packfile, pd);
 	    pd = NOTOK;
 	}
     }
     else {
 #endif /* POP */
 
+    /*
+     * Get the mail from file (usually mail spool)
+     */
     m_unknown (in);		/* the MAGIC invocation... */
     hghnum = msgnum = mp->hghmsg;
     for (i = 0;;) {
@@ -708,7 +749,8 @@ go_to_it: ;
 		if (noisy)
 		    fflush (stdout);
 
-		msgnum++, mp->hghmsg++;
+		msgnum++;
+		mp->hghmsg++;
 		mp->msgstats[msgnum] = EXISTS;
 #ifdef TMA
 		if (i == SCNENC) {
@@ -729,6 +771,7 @@ go_to_it: ;
 #ifdef POP
     }
 #endif /* POP */
+
 #ifndef	POP
     if (i < 0) {		/* error } */
 #else
@@ -759,7 +802,7 @@ go_to_it: ;
     if (noisy)
 	fflush (stdout);
 #ifdef POP
-    if (host && file)
+    if (host && packfile)
 	done (0);
 #endif /* POP */
 
@@ -776,14 +819,14 @@ go_to_it: ;
 		admonish (newmail, "error zero'ing");
 	    unlink(map_name(newmail));
 	}
-    }
-    else
+    } else {
 	if (noisy)
 	    printf ("%s not zero'd\n", newmail);
+    }
 
-    if (msgnum == hghnum)
+    if (msgnum == hghnum) {
 	admonish (NULL, "no messages incorporated");
-    else {
+    } else {
 	m_replace (pfolder, folder);	/* update current folder */
 	if (chgflag)
 	    mp->curmsg = hghnum + 1;
@@ -791,7 +834,7 @@ go_to_it: ;
 	if (mp->lowmsg == 0)
 	    mp->lowmsg = 1;
 	if (chgflag)		/* sigh... */
-	    m_setcur (mp, mp->curmsg);
+	    seq_setcur (mp, mp->curmsg);
     }
 
 #ifdef POP
@@ -811,9 +854,9 @@ go_to_it: ;
     else
 	fclose (in);
 
-    m_setvis (mp, 0);
-    m_sync (mp);
-    m_update ();	/* update the context file */
+    seq_setunseen (mp, 0);	/* set the Unseen-Sequence */
+    seq_save (mp);
+    m_update ();		/* update the context file */
 
 #ifdef TMA
     if (decflag && mp->numsel > 0) {
@@ -893,8 +936,8 @@ get_uucp_mail (void)
 void
 done (int status)
 {
-    if (file && pd != NOTOK)
-	mbx_close (file, pd);
+    if (packfile && pd != NOTOK)
+	mbx_close (packfile, pd);
 
     exit (status);
 }
@@ -911,8 +954,8 @@ pop_action (char *s)
 static int
 pop_pack (char *s)
 {
-    register int    j;
-    char    buffer[BUFSIZ];
+    int j;
+    char buffer[BUFSIZ];
 
     sprintf (buffer, "%s\n", s);
     for (j = 0; (j = stringdex (mmdlm1, buffer)) >= 0; buffer[j]++)
@@ -931,9 +974,9 @@ map_count (void)
     struct drop d;
     struct stat st;
 
-    if (stat (file, &st) == NOTOK)
+    if (stat (packfile, &st) == NOTOK)
 	return 0;
-    if ((md = open (cp = map_name (file), 0)) == NOTOK
+    if ((md = open (cp = map_name (packfile), O_RDONLY)) == NOTOK
 	    || map_chk (cp, md, &d, (long) st.st_size, 1)) {
 	if (md != NOTOK)
 	    close (md);
