@@ -61,7 +61,7 @@ static struct swit mhlswitches[] = {
     { "nomoreproc", 0 },
 #define	LENSW         10
     { "length lines", 0 },
-#define	WIDSW         11
+#define	WIDTHSW       11
     { "width columns", 0 },
 #define	SLEEPSW       12
     { "sleep seconds",  0 },
@@ -159,7 +159,7 @@ static struct pair pairs[] = {
     { "Resent-cc",       ADDRFMT },
     { "Resent-Bcc",      ADDRFMT },
     { "Face",            FACEFMT },
-    NULL
+    { NULL,              NULL }
 };
 
 struct triple {
@@ -189,7 +189,7 @@ static struct triple triples[] = {
     { "datefield",     DATEFMT,     ADDRFMT },
     { "newline",       0,           NONEWLINE },
     { "nonewline",     NONEWLINE,   0 },
-    NULL
+    { NULL,            0,           0 }
 };
 
 
@@ -302,13 +302,13 @@ mhl (int argc, char **argv)
     if ((cp = m_find (invo_name)) != NULL) {
 	ap = brkstring (getcpy (cp), " ", "\n");
 	ap = copyip (ap, arguments);
-    }
-    else
+    } else {
 	ap = arguments;
+    }
     copyip (argv + 1, ap);
     argp = arguments;
 
-    if (cp = getenv ("FACEPROC"))
+    if ((cp = getenv ("FACEPROC")))
 	faceproc = cp;
 
     vecp = 0;
@@ -379,7 +379,7 @@ mhl (int argc, char **argv)
 		    if ((length = atoi (cp)) < 1)
 			adios (NULL, "bad argument %s %s", argp[-2], cp);
 		    continue;
-		case WIDSW: 
+		case WIDTHSW: 
 		    if (!(cp = *argp++) || *cp == '-')
 			adios (NULL, "missing argument to %s", argp[-2]);
 		    if ((width = atoi (cp)) < 1)
@@ -427,22 +427,22 @@ mhl (int argc, char **argv)
     if (!folder)
 	folder = getenv ("mhfolder");
 
-    if (isatty (fileno (stdout)))
-	if (!nomore && !sc_hardcopy () && moreproc && *moreproc) {
+    if (isatty (fileno (stdout))) {
+	if (!nomore && !sc_hardcopy() && moreproc && *moreproc) {
 	    if (mhl_action) {
 		SIGNAL (SIGINT, SIG_IGN);
 		SIGNAL2 (SIGQUIT, quitser);
 	    }
 	    m_popen (moreproc);
 	    ontty = PITTY;
-	}
-	else {
+	} else {
 	    SIGNAL (SIGINT, SIG_IGN);
 	    SIGNAL2 (SIGQUIT, quitser);
 	    ontty = ISTTY;
 	}
-    else
+    } else {
 	ontty = NOTTY;
+    }
 
     mhl_format (form ? form : mhlformat, length, width);
 
@@ -527,7 +527,7 @@ mhl_format (char *file, int length, int width)
 	if (*bp == ';')
 	    continue;
 
-	if (cp = strchr(bp, '\n'))
+	if ((cp = strchr(bp, '\n')))
 	    *cp = 0;
 
 	if (*bp == ':') {
@@ -926,7 +926,7 @@ mhlfile (FILE *fp, char *mname, int ofilen, int ofilec)
 			    if (c2->c_flags & FACEDFLT) {
 				if (c2->c_face == NULL)
 				    face_format (c2);
-				if (holder.c_text = c2->c_face) {
+				if ((holder.c_text = c2->c_face)) {
 				    putcomp (c1, &holder, ONECOMP);
 				    holder.c_text = NULL;
 				}
@@ -1003,11 +1003,11 @@ mcomp_format (struct mcomp *c1, struct mcomp *c2)
 	FINDCOMP (cptr, "text");
 	if (cptr)
 	    cptr->c_text = ap;
-	if (cp = strrchr(ap, '\n'))	/* drop ending newline */
+	if ((cp = strrchr(ap, '\n')))	/* drop ending newline */
 	    if (!cp[1])
 		*cp = 0;
 
-	fmt_scan (c1->c_fmt, buffer, sizeof buffer - 1, dat);
+	fmt_scan (c1->c_fmt, buffer, sizeof(buffer) - 1, dat);
 	/* Don't need to append a newline, dctime() already did */
 	c2->c_text = getcpy (buffer);
 
@@ -1016,7 +1016,7 @@ mcomp_format (struct mcomp *c1, struct mcomp *c2)
     }
 
     (q = &pq)->pq_next = NULL;
-    while (cp = getname (ap)) {
+    while ((cp = getname (ap))) {
 	if ((p = (struct pqpair *) calloc ((size_t) 1, sizeof *p)) == NULL)
 	    adios (NULL, "unable to allocate pqpair memory");
 
@@ -1029,7 +1029,7 @@ mcomp_format (struct mcomp *c1, struct mcomp *c2)
 		char   *h, *o;
 		if ((h = mp->m_host) == NULL)
 		    h = LocalName ();
-		if (o = OfficialName (h))
+		if ((o = OfficialName (h)))
 		    h = o;
 		c2->c_face = concat ("address ", h, " ", mp->m_mbox,
 				    NULL);
@@ -1078,7 +1078,7 @@ add_queue (struct mcomp **head, struct mcomp **tail, char *name, char *text, int
 	adios (NULL, "unable to allocate comp memory");
 
     c1->c_flags = flags & ~INIT;
-    if (c1->c_name = name ? getcpy (name) : NULL)
+    if ((c1->c_name = name ? getcpy (name) : NULL))
 	c1->c_flags |= mcomp_flags (c1->c_name);
     c1->c_text = text ? getcpy (text) : NULL;
     if (flags & INIT) {
@@ -1228,11 +1228,11 @@ putcomp (struct mcomp *c1, struct mcomp *c2, int flag)
 			: strlen (c1->c_text ? c1->c_text : c1->c_name) + 2;
     count += c1->c_offset;
 
-    if (cp = oneline (c2->c_text, c1->c_flags))
+    if ((cp = oneline (c2->c_text, c1->c_flags)))
        putstr(cp);
     if (term == '\n')
 	putstr ("\n");
-    while (cp = oneline (c2->c_text, c1->c_flags)) {
+    while ((cp = oneline (c2->c_text, c1->c_flags))) {
 	lm = count;
 	if (flag == BODYCOMP
 		&& !(c1->c_flags & NOCOMPONENT))
@@ -1428,17 +1428,17 @@ face_format (struct mcomp *c1)
     if ((cp = c1->c_text) == NULL)
 	return;
 
-    if (cp = getname (cp)) {
-	if (mp = getm (cp, NULL, 0, AD_NAME, NULL)) {
+    if ((cp = getname (cp))) {
+	if ((mp = getm (cp, NULL, 0, AD_NAME, NULL))) {
 	    char *h, *o;
 	    if ((h = mp->m_host) == NULL)
 		h = LocalName ();
-	    if (o = OfficialName (h))
+	    if ((o = OfficialName (h)))
 		h = o;
 	    c1->c_face = concat ("address ", h, " ", mp->m_mbox, NULL);
 	}
 
-	while (cp = getname (cp))
+	while ((cp = getname (cp)))
 	    continue;
     }
 }
@@ -1461,7 +1461,7 @@ face_format (struct mcomp *c1)
 static int
 doface (struct mcomp *c1)
 {
-    int	i, result, sd;
+    int	result, sd;
     struct sockaddr_in in_socket;
     register struct sockaddr_in *isock = &in_socket;
     static int inited = OK;
@@ -1470,7 +1470,6 @@ doface (struct mcomp *c1)
     static ushort portno;
 
     if (inited == OK) {
-	ulong iaddr;
 	char *cp;
 	char **ap = brkstring (cp = getcpy (faceproc), " ", "\n");
 	struct hostent *hp;
