@@ -98,7 +98,7 @@ main(int argc, char **argv)
 	adios (maildir, "unable to change directory to");
 
     /* read folder and create message structure */
-    if (!(mp = m_gmsg (folder)))
+    if (!(mp = m_readfolder (folder)))
 	adios (NULL, "unable to read folder %s", folder);
 
     if ((mp = m_remsg (mp, 0, MAXFOLDER)) == NULL)
@@ -111,15 +111,15 @@ main(int argc, char **argv)
 	if (!m_convert (mp, msgs[i]))
 	    done (1);
 
-    m_setseq (mp);	/* set the previous-sequence */
+    seq_setprev (mp);	/* set the previous-sequence */
 
     /* print the path of all selected messages */
     for (i = mp->lowsel; i <= mp->hghsel; i++)
 	if (is_selected (mp, i))
 	    printf ("%s/%s\n", mp->foldpath, m_name (i));
 
-    m_sync (mp);	/* synchronize message sequences */
-    m_fmsg (mp);	/* free folder/message structure */
+    seq_save (mp);	/* synchronize message sequences */
+    m_freefolder (mp);	/* free folder/message structure */
     m_update ();	/* update the context file       */
     done (0);
 }
