@@ -122,9 +122,9 @@ main (int argc, char **argv)
     if ((cp = m_find (invo_name))) {
 	ap = brkstring (cp = getcpy (cp), " ", "\n");
 	ap = copyip (ap, arguments);
-    }
-    else
+    } else {
 	ap = arguments;
+    }
     copyip (argv + 1, ap);
     argp = arguments;
 
@@ -187,7 +187,10 @@ main (int argc, char **argv)
     }
 
 #ifdef POP
-    if (!host || !*host) {	/* -host not specified by user */
+    /*
+     * If -host is not specified by user
+     */
+    if (!host || !*host) {
 # ifdef HESIOD
 	/*
 	 * Scheme is:
@@ -202,6 +205,10 @@ main (int argc, char **argv)
 		strcmp(po->po_type, "POP") == 0)
 	    pophost = po->po_host;
 # endif /* HESIOD */
+	/*
+	 * If "pophost" is specified in mts.conf,
+	 * use it as default value.
+	 */
 	if (pophost && *pophost)
 	    host = pophost;
     }
@@ -210,40 +217,44 @@ main (int argc, char **argv)
     if (!host || rpop <= 0)
 	setuid (uid);
 #endif /* POP */
-    if (vecp == 0) {
-#ifdef POP
-	if (host)
-	    status = remotemail (host, user, rpop, notifysw, 1, snoop);
-	else
-#endif
-	  {
-	    char *home = (uid = geteuid()) ? home = getenv ("HOME") : NULL;
-	    if (home == NULL)
-	      {
-		pw = getpwnam (user);
-		if (pw == NULL)
-		  adios (NULL, "unable to get information about user");
-		if (home == NULL)
-		  home = pw->pw_dir;
-	      }
-	    status = checkmail (user, home, datesw, notifysw, 1);
-	  }
-    }
-    else {
+
+    if (vecp != 0)
 	vec[vecp] = NULL;
 
-	for (vecp = 0; cp = vec[vecp]; vecp++) {
 #ifdef POP
-	    if (host)
-		status += remotemail (host, cp, rpop, notifysw, 0, snoop);
+    if (host) {
+	if (vecp == 0) {
+	    status = remotemail (host, user, rpop, notifysw, 1, snoop);
+	} else {
+	    for (vecp = 0; vec[vecp]; vecp++)
+		status += remotemail (host, vec[vecp], rpop, notifysw, 0, snoop);
+	}
+    } else {
+#endif /* POP */
+
+    if (vecp == 0) {
+	char *home;
+
+	home = (uid = geteuid()) ? home = getenv ("HOME") : NULL;
+	if (home == NULL) {
+	    pw = getpwnam (user);
+	    if (pw == NULL)
+		adios (NULL, "unable to get information about user");
+	    if (home == NULL)
+		home = pw->pw_dir;
+	}
+	status = checkmail (user, home, datesw, notifysw, 1);
+    } else {
+	for (vecp = 0; vec[vecp]; vecp++) {
+	    if ((pw = getpwnam (vec[vecp])))
+		status += checkmail (pw->pw_name, pw->pw_dir, datesw, notifysw, 0);
 	    else
-#endif
-		if ((pw = getpwnam (cp)))
-		    status += checkmail (pw->pw_name, pw->pw_dir, datesw, notifysw, 0);
-		else
-		    advise (NULL, "no such user as %s", cp);
+		advise (NULL, "no such user as %s", vec[vecp]);
 	}
     }
+#ifdef POP
+    }		/* host == NULL */
+#endif
 
     done (status);
 }
@@ -321,10 +332,9 @@ checkmail (char *user, char *home, int datesw, int notifysw, int personal)
 		printf ("%s%s", mf & MMDFOLD ? "old" : "new",
 			mf & UUCPOK ? " Internet" : "");
 	    printf (" mail waiting");
-	}
-	else
+	} else {
 	    notifysw = 0;
-
+	}
 	status = 0;
     }
     else {
@@ -340,8 +350,7 @@ checkmail (char *user, char *home, int datesw, int notifysw, int personal)
 #ifndef	MF
     if (notifysw)
 	if (datesw && st.st_atime)
-	    printf ("; last read on %s",
-		    dasctime (dlocaltime ((time_t *) &st.st_atime), TW_NULL));
+	    printf ("; last read on %s", dtime (&st.st_atime, 1));
 #endif	/* MF */
     if (notifysw)
 	printf ("\n");
@@ -387,8 +396,7 @@ remotemail (char *host, char *user, int rpop, int notifysw, int personal, int sn
 	    notifysw = 0;
 
 	status = 0;
-    }
-    else {
+    } else {
 	if (notifysw & NT_NMAI)
 	    printf (personal ? "You don't %s%s" : "%s doesn't %s",
 		    personal ? "" : user, "have any mail waiting");
