@@ -11,6 +11,7 @@
  */
 
 #include <h/mh.h>
+#include <fcntl.h>
 #include <h/signals.h>
 #include <h/dropsbr.h>
 #include <h/fmt_scan.h>
@@ -183,7 +184,7 @@ int readid (int);
 void display_info (int);
 int expand (char *);
 void m_reset (void);
-void m_setcur (struct msgs *, int);
+void seq_setcur (struct msgs *, int);
 void padios (char *, char *, ...);
 void padvise (char *, char *, ...);
 
@@ -693,7 +694,7 @@ fsetup (char *folder)
     maildir = m_maildir (folder);
     if (chdir (maildir) == NOTOK)
 	padios (maildir, "unable to change directory to");
-    if (!(mp = m_gmsg (folder)))
+    if (!(mp = m_readfolder (folder)))
 	padios (NULL, "unable to read folder %s", folder);
     if (mp->hghmsg == 0)
 	padios (NULL, "no messages in %s", folder);
@@ -975,7 +976,7 @@ msh_ready (int msgnum, int full)
 			break;
 		    }
 
-	    if ((fd = open (cp = m_name (msgnum), 0)) == NOTOK)
+	    if ((fd = open (cp = m_name (msgnum), O_RDONLY)) == NOTOK)
 		padios (cp, "unable to open message");
 	    Msgs[msgnum].m_top = fd;
 	    numfds++;
@@ -985,7 +986,7 @@ msh_ready (int msgnum, int full)
 	    padios ("cached message", "unable to dup");
 	if ((yp = fdopen (fd, "r")) == NULL)
 	    padios (NULL, "unable to fdopen cached message");
-	fseek (yp, 0L, 0);
+	fseek (yp, 0L, SEEK_SET);
 	return yp;
     }
 
@@ -1004,15 +1005,15 @@ msh_ready (int msgnum, int full)
 
 	    m_eomsbr ((int (*)()) 0);	/* XXX */
 	    msg_style = MS_DEFAULT;	/*  .. */
-	    fseek (yp, 0L, 0);
+	    fseek (yp, 0L, SEEK_SET);
 	    return yp;
 	}
 
-	fseek (fp, 0L, 2);
+	fseek (fp, 0L, SEEK_END);
 	fwrite (mmdlm1, 1, strlen (mmdlm1), fp);
 	if (fflush (fp))
 	    padios ("temporary file", "write error on");
-	fseek (fp, 0L, 2);
+	fseek (fp, 0L, SEEK_END);
 	pos1 = ftell (fp);
 
 	yp = fp;
@@ -1020,7 +1021,7 @@ msh_ready (int msgnum, int full)
 	    padios (NULL, "%s", response);
 	yp = NULL;
 
-	fseek (fp, 0L, 2);
+	fseek (fp, 0L, SEEK_END);
 	pos2 = ftell (fp);
 	fwrite (mmdlm2, 1, strlen (mmdlm2), fp);
 	if (fflush (fp))
@@ -1034,7 +1035,7 @@ msh_ready (int msgnum, int full)
 #endif /* BPOP */
 
     m_eomsbr ((int (*)()) 0);	/* XXX */
-    fseek (fp, Msgs[msgnum].m_start, 0);
+    fseek (fp, Msgs[msgnum].m_start, SEEK_SET);
     return fp;
 }
 
@@ -1042,7 +1043,7 @@ msh_ready (int msgnum, int full)
 static int
 check_folder (int scansw)
 {
-    int flags, i, low, hgh, msgp;
+    int seqnum, i, low, hgh, msgp;
     struct stat st;
 
 #ifdef BPOP
@@ -1058,9 +1059,9 @@ check_folder (int scansw)
 	mtime = st.st_mtime;
 
 	low = mp->hghmsg + 1;
-	m_fmsg (mp);		/* free folder/message info */
+	m_freefolder (mp);		/* free folder/message info */
 
-	if (!(mp = m_gmsg (fmsh)))
+	if (!(mp = m_readfolder (fmsh)))
 	    padios (NULL, "unable to re-read folder %s", fmsh);
 
 	hgh = mp->hghmsg;
@@ -1102,9 +1103,11 @@ check_folder (int scansw)
 	padios (NULL, "unable to allocate folder storage");
 
     low = mp->hghmsg + 1, hgh = msgp;
-    flags = scansw ? m_seqflag (mp, "unseen") : 0;
+    seqnum = scansw ? seq_getnum (mp, "unseen") : -1;
     for (i = mp->hghmsg + 1; i <= msgp; i++) {
-	mp->msgstats[i] = EXISTS | flags;
+	set_exists(mp, i);
+	if (seqnum != -1)
+	    add_sequence(mp, seqnum, i);
 	mp->nummsg++;
     }
     mp->hghmsg = msgp;
@@ -1155,33 +1158,33 @@ scanstring (char *arg)
 int
 readids (int id)
 {
-    register int cur, flags, i, msgnum;
+    register int cur, seqnum, i, msgnum;
 
     if (mp->curmsg == 0)
-	m_setcur (mp, mp->lowmsg);
-    if (id <= 0 || (flags = m_seqflag (mp, "unseen")) == 0)
+	seq_setcur (mp, mp->lowmsg);
+    if (id <= 0 || (seqnum = seq_getnum (mp, "unseen")) == -1)
 	return;
 
     for (msgnum = mp->hghmsg; msgnum >= mp->lowmsg; msgnum--)
-	mp->msgstats[msgnum] |= flags;
+	add_sequence(mp, seqnum, msgnum);
 
     if (id != 1) {
 	cur = mp->curmsg;
 
 	for (msgnum = mp->hghmsg; msgnum >= mp->lowmsg; msgnum--)
-	  if (mp->msgstats[msgnum] & EXISTS)		/* FIX */
+	  if (does_exist(mp, msgnum))		/* FIX */
 	    if ((i = readid (msgnum)) > 0 && i < id) {
 		cur = msgnum + 1;
-		mp->msgstats[msgnum] &= ~flags;
+		clear_sequence(mp, seqnum, msgnum);
 		break;
 	    }
 	for (i = mp->lowmsg; i < msgnum; i++)
-	    mp->msgstats[i] &= ~flags;
+	    clear_sequence(mp, seqnum, i);
 
 	if (cur > mp->hghmsg)
 	    cur = mp->hghmsg;
 
-	m_setcur (mp, cur);
+	seq_setcur (mp, cur);
     }
 
     if ((gap = 1 < id && id < (i = readid (mp->lowmsg)) ? id : 0) && !vmh)
@@ -1245,7 +1248,7 @@ readid (int msgnum)
 void
 display_info (int scansw)
 {
-    int flags, sd;
+    int seqnum, sd;
 
     interactive = isatty (fileno (stdout));
     if (sp == NULL) {
@@ -1281,9 +1284,9 @@ display_info (int scansw)
 		mp->curmsg, mp->hghmsg);
     }
 
-    if ((flags = m_seqflag (mp, "unseen"))
+    if (((seqnum = seq_getnum (mp, "unseen")) != -1)
 	    && scansw
-	    && (mp->msgstats[mp->hghmsg] & flags))
+	    && in_sequence(mp, seqnum, mp->hghmsg))
 	scanstring ("unseen");
 }
 
@@ -1291,15 +1294,15 @@ display_info (int scansw)
 static void
 write_ids (void)
 {
-    int i = 0, flags, msgnum;
+    int i = 0, seqnum, msgnum;
     char buffer[80];
 
     if (pfd <= 1)
 	return;
 
-    if (flags = m_seqflag (mp, "unseen"))
+    if ((seqnum = seq_getnum (mp, "unseen")) != -1)
 	for (msgnum = mp->hghmsg; msgnum >= mp->lowmsg; msgnum--)
-	    if (!(mp->msgstats[msgnum] & flags)) {
+	    if (!in_sequence(mp, seqnum, msgnum)) {
 		if (Msgs[msgnum].m_bboard_id == 0)
 		    readid (msgnum);
 		if ((i = Msgs[msgnum].m_bboard_id) > 0)
@@ -1307,7 +1310,7 @@ write_ids (void)
 	    }
 
     sprintf (buffer, "%d %d\n", i, Msgs[mp->hghmsg].m_bboard_id);
-    write (pfd, buffer, sizeof buffer);
+    write (pfd, buffer, sizeof(buffer));
     close (pfd);
     pfd = NOTOK;
 }
@@ -1789,7 +1792,7 @@ void
 m_reset (void)
 {
     write_ids ();
-    m_fmsg (mp);	/* free folder/message info */
+    m_freefolder (mp);	/* free folder/message info */
     myname = NULL;
 #ifdef	BPOP
     if (pmsh) {
@@ -1801,7 +1804,7 @@ m_reset (void)
 
 
 void
-m_setcur (struct msgs *mp, int msgnum)
+seq_setcur (struct msgs *mp, int msgnum)
 {
     if (mp->curmsg == msgnum)
 	return;
@@ -2230,8 +2233,9 @@ ttyNaux (struct Cmd *cmdp, char *s)
     if (cmdp && init_io (cmdp, vmh) == NOTOK)
 	return NOTOK;
 
+    /* XXX: fseek() too tricky for our own good */
     if (!fmsh)
-	fseek (fp, 0L, 0);/* XXX: fseek() too tricky for our own good */
+	fseek (fp, 0L, SEEK_SET);
 
     vmhtty = NOTOK;
     switch (rc2rc (RC_TTY, s ? strlen (s) : 0, s, rc)) {
@@ -2303,8 +2307,9 @@ winN (struct Cmd *cmdp, int n, int eof)
 
     initrc (rc);
 
+    /* XXX: fseek() too tricky for our own good */
     if (!fmsh)
-	fseek (fp, 0L, 0);/* XXX: fseek() too tricky for our own good */
+	fseek (fp, 0L, SEEK_SET);
 
     vmhpid = OK;
 
@@ -2387,7 +2392,7 @@ winN (struct Cmd *cmdp, int n, int eof)
 		padios ("diagnostic output", "unable to dup");
 
 	    close (0);
-	    if ((i = open ("/dev/null", 0)) != NOTOK && i != fileno (stdin)) {
+	    if ((i = open ("/dev/null", O_RDONLY)) != NOTOK && i != fileno (stdin)) {
 		dup2 (i, fileno (stdin));
 		close (i);
 	    }
@@ -2463,8 +2468,9 @@ winX (int n)
     rc = &rcs;
     initrc (rc);
 
+    /* XXX: fseek() too tricky for our own good */
     if (!fmsh)
-	fseek (fp, 0L, 0);/* XXX: fseek() too tricky for our own good */
+	fseek (fp, 0L, SEEK_SET);
 
     sprintf (buffer, "%d", n);
     switch (str2rc (RC_WIN, buffer, rc)) {
@@ -2496,7 +2502,7 @@ winX (int n)
 
 	case OK: 
 	    close (fileno (stdin));
-	    if ((i = open ("/dev/null", 0)) != NOTOK && i != fileno (stdin)) {
+	    if ((i = open ("/dev/null", O_RDONLY)) != NOTOK && i != fileno (stdin)) {
 		dup2 (i, fileno (stdin));
 		close (i);
 	    }
