@@ -82,7 +82,7 @@ forkcmd (char **args, char *pgm)
     if (fmsh) {
 	m_delete (pfolder);
 	m_replace (pfolder, fmsh);	/* update current folder   */
-	m_sync (mp);
+	seq_save (mp);
 	m_update ();			/* update the context file */
     }
     fflush (stdout);
@@ -214,14 +214,14 @@ distcmd (char **args)
 	msg = "cur";
     if (!m_convert (mp, msg))
 	return;
-    m_setseq (mp);
+    seq_setprev (mp);
 
     if (mp->numsel > 1) {
 	advise (NULL, "only one message at a time!");
 	return;
     }
     process (mp->hghsel, cmd_name, vecp, vec);
-    m_setcur (mp, mp->hghsel);
+    seq_setcur (mp, mp->hghsel);
 }
 
 
@@ -303,7 +303,7 @@ explcmd (char **args)
     for (msgnum = 0; msgnum < msgp; msgnum++)
 	if (!m_convert (mp, msgs[msgnum]))
 	    return;
-    m_setseq (mp);
+    seq_setprev (mp);
 
     smsgs = (struct Msg *)
 		calloc ((size_t) (MAXFOLDER + 2), sizeof *smsgs);
@@ -322,10 +322,10 @@ explcmd (char **args)
     free ((char *) smsgs);
 
     if (inplace)
-	m_setcur (mp, mp->lowsel);
+	seq_setcur (mp, mp->lowsel);
     else
 	if (hi <= mp->hghmsg)
-	    m_setcur (mp, hi);
+	    seq_setcur (mp, hi);
 
     mp->msgflags |= MODIFIED;
     modified++;
@@ -355,7 +355,7 @@ burst (struct Msg *smsgs, int msgnum, int inplace, int quietsw, int verbosw)
 	    pos += (long) strlen (buffer);
 	if (feof (zp) || pos >= Msgs[msgnum].m_stop)
 	    break;
-	fseek (zp, pos, 0);
+	fseek (zp, pos, SEEK_SET);
 	smsgs[msgp].m_start = pos;
 
 	for (c = 0;
@@ -533,7 +533,7 @@ filecmd (char **args)
     for (msgnum = 0; msgnum < msgp; msgnum++)
 	if (!m_convert (mp, msgs[msgnum]))
 	    return;
-    m_setseq (mp);
+    seq_setprev (mp);
 
     interrupted = 0;
     for (msgnum = mp->lowsel;
@@ -546,7 +546,7 @@ filecmd (char **args)
 	    }
 
     if (mp->numsel != mp->nummsg || linksw)
-	m_setcur (mp, mp->hghsel);
+	seq_setcur (mp, mp->hghsel);
     if (!linksw)
 	rmm ();
 }
@@ -743,13 +743,13 @@ foldcmd (char **args)
     if (msg) {
 	if (!m_convert (mp, msg))
 	    return;
-	m_setseq (mp);
+	seq_setprev (mp);
 
 	if (mp->numsel > 1) {
 	    advise (NULL, "only one message at a time!");
 	    return;
 	}
-	m_setcur (mp, mp->hghsel);
+	seq_setcur (mp, mp->hghsel);
     }
 
     if (packsw) {
@@ -774,7 +774,7 @@ foldcmd (char **args)
 		    }
 		    mp->msgstats[hole] = mp->msgstats[msgnum];
 		    if (mp->curmsg == msgnum)
-			m_setcur (mp, hole);
+			seq_setcur (mp, hole);
 		}
 		hole++;
 	    }
@@ -944,7 +944,7 @@ forwcmd (char **args)
     for (msgnum = 0; msgnum < msgp; msgnum++)
 	if (!m_convert (mp, msgs[msgnum]))
 	    return;
-    m_setseq (mp);
+    seq_setprev (mp);
 
     if (filter) {
 	strcpy (buf, filter);
@@ -957,7 +957,7 @@ forwcmd (char **args)
 	}
     }
     forw (cmd_name, filter, vecp, vec);
-    m_setcur (mp, mp->hghsel);
+    seq_setcur (mp, mp->hghsel);
     if (filter)
 	free (filter);
 }
@@ -1239,28 +1239,17 @@ markcmd (char **args)
     }
     seqs[seqp] = NULL;
 
-    if (addsw)
-	for (seqp = 0; seqs[seqp]; seqp++) {
-	    if (zerosw && !m_seqnew (mp, seqs[seqp], 0))
+    if (addsw) {
+	for (seqp = 0; seqs[seqp]; seqp++)
+	    if (!seq_addsel (mp, seqs[seqp], 0, zerosw))
 		return;
-	    for (msgnum = mp->lowsel; msgnum <= mp->hghsel; msgnum++)
-		if (is_selected (mp, msgnum))
-		    if (!m_seqadd (mp, seqs[seqp], msgnum, 0))
-			return;
-	}
+    }
 
-    if (deletesw)
-	for (seqp = 0; seqs[seqp]; seqp++) {
-	    if (zerosw)
-		for (msgnum = mp->lowmsg; msgnum <= mp->hghmsg; msgnum++)
-		    if (mp->msgstats[msgnum] & EXISTS)
-			if (!m_seqadd (mp, seqs[seqp], msgnum, 0))
-			    return;
-	    for (msgnum = mp->lowsel; msgnum <= mp->hghsel; msgnum++)
-		if (is_selected (mp, msgnum))
-		    if (!m_seqdel (mp, seqs[seqp], msgnum))
-			return;
-	}
+    if (deletesw) {
+	for (seqp = 0; seqs[seqp]; seqp++)
+	    if (!seq_delsel (mp, seqs[seqp], 0, zerosw))
+		return;
+    }
 
 #define empty(s) ((s) ? (s) : "")
 
@@ -1269,10 +1258,10 @@ markcmd (char **args)
 	    for (i = 0; mp->msgattrs[i]; i++)
 		printf ("%s%s: %s\n", mp->msgattrs[i],
 			is_seq_private (mp, i) ? " (private)" : "",
-			empty(m_seq (mp, mp->msgattrs[i])));
+			empty(seq_list(mp, mp->msgattrs[i])));
 	} else {
 	    for (seqp = 0; seqs[seqp]; seqp++)
-		printf ("%s%s: %s\n", seqs[seqp], empty(m_seq (mp, seqs[seqp])));
+		printf ("%s%s: %s\n", seqs[seqp], empty(seq_list(mp, seqs[seqp])));
 	}
 
 #undef empty
@@ -1288,7 +1277,7 @@ markcmd (char **args)
 			    Msgs[msgnum].m_bboard_id, Msgs[msgnum].m_top,
 			    Msgs[msgnum].m_start, Msgs[msgnum].m_stop,
 			    sprintb (buf, (unsigned) mp->msgstats[msgnum],
-				m_seqbits (mp)));
+				seq_bits (mp)));
 		    if (Msgs[msgnum].m_scanl)
 			printf ("%s", Msgs[msgnum].m_scanl);
 		}			    
@@ -1442,7 +1431,7 @@ mhncmd (char **args)
     for (msgnum = 0; msgnum < msgp; msgnum++)
 	if (!m_convert (mp, msgs[msgnum]))
 	    return;
-    m_setseq (mp);
+    seq_setprev (mp);
 
     interrupted = 0;
     for (msgnum = mp->lowsel;
@@ -1454,7 +1443,7 @@ mhncmd (char **args)
 		mp->numsel--;
 	    }
 
-    m_setcur (mp, mp->hghsel);
+    seq_setcur (mp, mp->hghsel);
 }
 
 #endif /* MIME */
@@ -1530,7 +1519,7 @@ packcmd (char **args)
     for (msgnum = 0; msgnum < msgp; msgnum++)
 	if (!m_convert (mp, msgs[msgnum]))
 	    goto done_pack;
-    m_setseq (mp);
+    seq_setprev (mp);
 
     if ((md = mbx_open (file, mbx_style, getuid (), getgid (), m_gmprot ())) == NOTOK) {
 	advise (file, "unable to open");
@@ -1543,7 +1532,7 @@ packcmd (char **args)
     mbx_close (file, md);
 
     if (mp->hghsel != mp->curmsg)
-	m_setcur (mp, mp->lowsel);
+	seq_setcur (mp, mp->lowsel);
 
 done_pack: ;
     free (file);
@@ -1741,7 +1730,7 @@ pattern: ;
     for (msgnum = 0; msgnum < msgp; msgnum++)
 	if (!m_convert (mp, msgs[msgnum]))
 	    return;
-    m_setseq (mp);
+    seq_setprev (mp);
 
     interrupted = 0;
     if (!pcompile (vec, NULL))
@@ -1780,14 +1769,9 @@ pattern: ;
     }
 
     seqs[seqp] = NULL;
-    for (seqp = 0; seqs[seqp]; seqp++) {
-	if (zerosw && !m_seqnew (mp, seqs[seqp], 0))
+    for (seqp = 0; seqs[seqp]; seqp++)
+	if (!seq_addsel (mp, seqs[seqp], 0, zerosw))
 	    return;
-	for (msgnum = mp->lowsel; msgnum <= mp->hghsel; msgnum++)
-	    if (is_selected (mp, msgnum))
-		if (!m_seqadd (mp, seqs[seqp], msgnum, 0))
-		    return;
-    }
 
     printf ("%d hit%s\n", mp->numsel, mp->numsel == 1 ? "" : "s");
 }
@@ -1916,14 +1900,14 @@ replcmd (char **args)
 	msg = "cur";
     if (!m_convert (mp, msg))
 	return;
-    m_setseq (mp);
+    seq_setprev (mp);
 
     if (mp->numsel > 1) {
 	advise (NULL, "only one message at a time!");
 	return;
     }
     process (mp->hghsel, cmd_name, vecp, vec);
-    m_setcur (mp, mp->hghsel);
+    seq_setcur (mp, mp->hghsel);
 }
 
 
@@ -1967,7 +1951,7 @@ rmmcmd (char **args)
     for (msgnum = 0; msgnum < msgp; msgnum++)
 	if (!m_convert (mp, msgs[msgnum]))
 	    return;
-    m_setseq (mp);
+    seq_setprev (mp);
 
     rmm ();
 }
@@ -2142,7 +2126,7 @@ scancmd (char **args)
     for (msgnum = 0; msgnum < msgp; msgnum++)
 	if (!m_convert (mp, msgs[msgnum]))
 	    return;
-    m_setseq (mp);
+    seq_setprev (mp);
 
     nfs = new_fs (form, format, FORMAT);
     if (scanl) {		/* force scansbr to (re)compile format */
@@ -2316,7 +2300,7 @@ void
 showcmd (char **args)
 {
     int	headersw = 1, nshow = 0, msgp = 0, vecp = 1;
-    int mhl = 0, seen = 0, mode = 0, i, msgnum;
+    int mhl = 0, seqnum = -1, mode = 0, i, msgnum;
     char *cp, *proc = showproc, buf[BUFSIZ];
     char *msgs[MAXARGS], *vec[MAXARGS];
 
@@ -2394,7 +2378,7 @@ showcmd (char **args)
     for (msgnum = 0; msgnum < msgp; msgnum++)
 	if (!m_convert (mp, msgs[msgnum]))
 	    return;
-    m_setseq (mp);
+    seq_setprev (mp);
 
 #ifdef MIME
     if (!nshow && !getenv ("NOMHNPROC"))
@@ -2417,15 +2401,15 @@ showcmd (char **args)
 	}
 
 finish: ;
-    seen = m_seqflag (mp, "unseen");
+    seqnum = seq_getnum (mp, "unseen");
     vec[0] = r1bindex (proc, '/');
     if (mhl) {
 	msgp = vecp;
 	for (msgnum = mp->lowsel; msgnum <= mp->hghsel; msgnum++)
 	    if (is_selected (mp, msgnum)) {
 		vec[vecp++] = getcpy (m_name (msgnum));
-		if (seen)
-		    m_seqdel (mp, "unseen", msgnum);
+		if (seqnum != -1)
+		    seq_delmsg (mp, "unseen", msgnum);
 	    }
 	vec[vecp] = NULL;
 	if (mp->numsel == 1 && headersw)
@@ -2434,8 +2418,7 @@ finish: ;
 	m_eomsbr ((int (*)()) 0);
 	while (msgp < vecp)
 	    free (vec[msgp++]);
-    }
-    else {
+    } else {
 	interrupted = 0;
 	for (msgnum = mp->lowsel;
 		msgnum <= mp->hghsel && !interrupted;
@@ -2456,15 +2439,15 @@ finish: ;
 			else
 			    process (msgnum, proc, vecp, vec);
 
-			if (seen)
-			    m_seqdel (mp, "unseen", msgnum);
+			if (seqnum != -1)
+			    seq_delmsg (mp, "unseen", msgnum);
 			continue;
 		}
 		break;
 	    }
     }
 
-    m_setcur (mp, mp->hghsel);
+    seq_setcur (mp, mp->hghsel);
 }
 
 
@@ -2812,9 +2795,9 @@ sortcmd (char **args)
     for (msgnum = 0; msgnum < msgp; msgnum++)
 	if (!m_convert (mp, msgs[msgnum]))
 	    return;
-    m_setseq (mp);
+    seq_setprev (mp);
 
-    twscopy (&tb, dtwstime ());
+    twscopy (&tb, dlocaltimenow ());
 
     for (msgnum = mp->lowsel; msgnum <= mp->hghsel; msgnum++) {
 	if (Msgs[msgnum].m_scanl) {
@@ -2843,7 +2826,7 @@ sortcmd (char **args)
 	}
 	mp->msgstats[msgnum] = Msgs[msgnum].m_stats & ~CUR;
 	if (Msgs[msgnum].m_stats & CUR)
-	    m_setcur (mp, msgnum);
+	    seq_setcur (mp, msgnum);
     }
 	    
     mp->msgflags |= MODIFIED;
@@ -3002,7 +2985,7 @@ process (int msgnum, char *proc, int vecp, char **vec)
 	strcpy (tmpfil, m_name (msgnum));
 	m_delete (pfolder);
 	m_replace (pfolder, fmsh);	/* update current folder   */
-	m_sync (mp);
+	seq_save (mp);
 	m_update ();			/* update the context file */
 	goto ready;
     }
