@@ -1,11 +1,12 @@
 
 /*
- * packf.c -- pack a folder
+ * packf.c -- pack a nmh folder into a file
  *
  * $Id$
  */
 
 #include <h/mh.h>
+#include <fcntl.h>
 #include <h/dropsbr.h>
 #include <errno.h>
 
@@ -47,9 +48,9 @@ main (int argc, char **argv)
     if ((cp = m_find (invo_name)) != NULL) {
 	ap = brkstring (cp = getcpy (cp), " ", "\n");
 	ap = copyip (ap, arguments);
-    }
-    else
+    } else {
 	ap = arguments;
+    }
     copyip (argv + 1, ap);
     argp = arguments;
 
@@ -119,7 +120,7 @@ main (int argc, char **argv)
 	adios (maildir, "unable to change directory to ");
 
     /* read folder and create message structure */
-    if (!(mp = m_gmsg (folder)))
+    if (!(mp = m_readfolder (folder)))
 	adios (NULL, "unable to read folder %s", folder);
 
     if (mp->hghmsg == 0)
@@ -129,14 +130,15 @@ main (int argc, char **argv)
     for (msgnum = 0; msgnum < msgp; msgnum++)
 	if (!m_convert (mp, msgs[msgnum]))
 	    done (1);
-    m_setseq (mp);	/* set the previous-sequence */
+    seq_setprev (mp);	/* set the previous-sequence */
 
-    if ((md = mbx_open (file, mbx_style, getuid (), getgid (), m_gmprot ())) == NOTOK)
+    if ((md = mbx_open(file, mbx_style, getuid(), getgid(), m_gmprot())) == NOTOK)
 	adios (file, "unable to open");
 
+    /* copy all the SELECTED messages to the file */
     for (msgnum = mp->lowsel; msgnum <= mp->hghsel; msgnum++)
 	if (is_selected(mp, msgnum)) {
-	    if ((fd = open (msgnam = m_name (msgnum), 0)) == NOTOK) {
+	    if ((fd = open (msgnam = m_name (msgnum), O_RDONLY)) == NOTOK) {
 		admonish (msgnam, "unable to read message");
 		break;
 	    }
@@ -150,9 +152,9 @@ main (int argc, char **argv)
 
     m_replace (pfolder, folder);	/* update current folder         */
     if (mp->hghsel != mp->curmsg)
-	m_setcur (mp, mp->lowsel);
-    m_sync (mp);
-    m_fmsg (mp);			/* free folder/message structure */
+	seq_setcur (mp, mp->lowsel);
+    seq_save (mp);
+    m_freefolder (mp);			/* free folder/message structure */
     m_update ();			/* update the context file       */
     done (0);
 }
