@@ -80,9 +80,9 @@ main (int argc, char **argv)
     if ((cp = m_find (invo_name)) != NULL) {
 	ap = brkstring (cp = getcpy (cp), " ", "\n");
 	ap = copyip (ap, arguments);
-    }
-    else
+    } else {
 	ap = arguments;
+    }
     copyip (argv + 1, ap);
     argp = arguments;
 
@@ -186,7 +186,7 @@ main (int argc, char **argv)
 	adios (maildir, "unable to change directory to");
 
     /* read folder and create message structure */
-    if (!(mp = m_gmsg (folder)))
+    if (!(mp = m_readfolder (folder)))
 	adios (NULL, "unable to read folder %s", folder);
 
     if (mp->hghmsg == 0)
@@ -196,7 +196,7 @@ main (int argc, char **argv)
     for (msgnum = 0; msgnum < msgp; msgnum++)
 	if (!m_convert (mp, msgs[msgnum]))
 	    done (1);
-    m_setseq (mp);	/* set the previous-sequence */
+    seq_setprev (mp);	/* set the previous-sequence */
 
     if (seqp == 0)
 	listsw++;
@@ -237,15 +237,17 @@ main (int argc, char **argv)
 	adios (NULL, "no messages match specification");
 
     seqs[seqp] = NULL;
-    for (seqp = 0; seqs[seqp]; seqp++) {
-	if (zerosw && !m_seqnew (mp, seqs[seqp], publicsw))
-	    done (1);
-	for (msgnum = mp->lowsel; msgnum <= mp->hghsel; msgnum++)
-	    if (is_selected (mp, msgnum))
-		if (!m_seqadd (mp, seqs[seqp], msgnum, publicsw))
-		    done (1);
-    }
 
+    /*
+     * Add the matching messages to sequences
+     */
+    for (seqp = 0; seqs[seqp]; seqp++)
+	if (!seq_addsel (mp, seqs[seqp], publicsw, zerosw))
+	    done (1);
+
+    /*
+     * Print the name of all the matches
+     */
     if (listsw) {
 	for (msgnum = mp->lowsel; msgnum <= mp->hghsel; msgnum++)
 	    if (is_selected (mp, msgnum))
@@ -255,8 +257,8 @@ main (int argc, char **argv)
     }
 
     m_replace (pfolder, folder);	/* update current folder         */
-    m_sync (mp);
-    m_fmsg (mp);			/* free folder/message structure */
+    seq_save (mp);			/* synchronize message sequences */
+    m_freefolder (mp);			/* free folder/message structure */
     m_update ();			/* update the context file       */
     done (0);
 }
