@@ -60,7 +60,7 @@ static struct swit  switches[] = {
     { "norpop", RPOPminc (-6) },
 #define	USERSW                 11
     { "user user", 0 },
-#define	WIDSW                  12
+#define	WIDTHSW                12
     { "width columns", 0 },
 #define VERSIONSW              13
     { "version", 0 },
@@ -151,7 +151,7 @@ main (int argc, char **argv)
 		    form = NULL;
 		    continue;
 
-		case WIDSW: 
+		case WIDTHSW: 
 		    if (!(cp = *argp++) || *cp == '-')
 			adios (NULL, "missing argument to %s", argp[-2]);
 		    width = atoi (cp);
@@ -236,7 +236,7 @@ main (int argc, char **argv)
 
     if (chdir (maildir) == NOTOK)
 	adios (maildir, "unable to change directory to");
-    if (!(mp = m_gmsg (folder)))
+    if (!(mp = m_readfolder (folder)))
 	adios (NULL, "unable to read folder %s", folder);
 
 #ifdef BPOP
@@ -247,9 +247,10 @@ main (int argc, char **argv)
 
     popi();
     pop_quit();
+
     m_replace (pfolder, folder);	/* update current folder   */
-    m_setvis (mp, 0);
-    m_sync (mp);
+    seq_setunseen (mp, 0);		/* set the Unseen-Sequence */
+    seq_save (mp);
     m_update ();			/* update the context file */
     done (0);
 
