@@ -133,12 +133,12 @@ pop_init (char *host, char *user, char *pass, int snoop)
 #endif
 
 #ifndef NNTP
-#ifndef KPOP
+# ifndef KPOP
     if ((fd1 = client (host, "tcp", POPSERVICE, rpop, response)) == NOTOK)
-#else	/* KPOP */
+# else	/* KPOP */
     sprintf (buffer, "%s/%s", POPSERVICE, "kpop");
     if ((fd1 = client (host, "tcp", buffer, rpop, response)) == NOTOK)
-#endif
+# endif
 #else	/* NNTP */
     if ((fd1 = client (host, "tcp", "nntp", rpop, response)) == NOTOK)
 #endif
@@ -169,8 +169,8 @@ pop_init (char *host, char *user, char *pass, int snoop)
 		fprintf (stderr, "<--- %s\n", response);
 #ifndef	NNTP
 	    if (*response == '+') {
-#ifndef KPOP
-#ifdef APOP
+# ifndef KPOP
+#  ifdef APOP
 		if (apop < 0) {
 		    char *cp = pop_auth (user, pass);
 
@@ -178,16 +178,16 @@ pop_init (char *host, char *user, char *pass, int snoop)
 			return OK;
 		}
 		else
-#endif /* apop */
+#  endif /* APOP */
 		if (command ("USER %s", user) != NOTOK
 		    && command ("%s %s", rpop ? "RPOP" : (pophack++, "PASS"),
 					pass) != NOTOK)
 		return OK;
-#else /* KPOP */
+# else /* KPOP */
 		if (command ("USER %s", user) != NOTOK
 		    && command ("PASS %s", pass) != NOTOK)
 		return OK;
-#endif
+# endif
 	    }
 #else /* NNTP */
 	    if (*response < CHAR_ERR) {
@@ -208,7 +208,8 @@ pop_init (char *host, char *user, char *pass, int snoop)
 	    fclose (output);
 	    return NOTOK;
     }
-/* NOTREACHED */
+
+    return NOTOK;	/* NOTREACHED */
 }
 
 #ifdef NNTP
@@ -594,7 +595,8 @@ vcommand (const char *fmt, va_list ap)
 		fprintf (stderr, "%s\n", response);
 	    return NOTOK;
     }
-/* NOTREACHED */
+
+    return NOTOK;	/* NOTREACHED */
 }
 
 
