@@ -6,6 +6,7 @@
  */
 
 #include <h/mh.h>
+#include <fcntl.h>
 #include <h/signals.h>
 #include <h/addrsbr.h>
 #include <h/aliasbr.h>
@@ -180,8 +181,7 @@ static struct headers NHeaders[] = {
     { "Dcc",         HADR|HTRY|HDCC|HNIL, MVIS },	/* sorta cc & bcc combined */
     { "Message-ID",  HBAD,                0 },
     { "Fcc",         HFCC,                0 },
-
-    NULL
+    { NULL,          NULL,                NULL }
 };
 
 static struct headers RHeaders[] = {
@@ -207,30 +207,29 @@ static struct headers RHeaders[] = {
     { "cc",                HADR|HNIL,           0 },
     { "Bcc",               HADR|HTRY|HBCC|HNIL, 0 },
     { "Fcc",               HIGN,                0 },
-
-    NULL
+    { NULL,                NULL,                NULL }
 };
 
 static short fccind = 0;	/* index into fccfold[] */
 static short outputlinelen = OUTPUTLINELEN;
 
-static int pfd = NOTOK;		/* fd to write annotation list to  */
-static uid_t myuid= -1;		/* my user id                      */
-static gid_t mygid= -1;		/* my group id                     */
-static int recipients = 0;	/* how many people will get a copy */
-static int unkadr = 0;		/* how many of those were unknown  */
-static int badadr = 0;		/* number of bad addrs             */
-static int badmsg = 0;		/* message has bad semantics       */
-static int verbose = 0;		/* spell it out                    */
-static int format = 1;		/* format addresses                */
-static int mime = 0;		/* use MIME-style encapsulations   */
-static int msgid = 0;		/* add msgid                       */
-static int debug = 0;		/* debugging post                  */
-static int watch = 0;		/* watch the delivery process      */
-static int whomsw = 0;		/* we are whom not post            */
-static int checksw = 0;		/* whom -check                     */
-static int linepos=0;		/* putadr()'s position on the line */
-static int nameoutput=0;	/* putadr() has output header name */
+static int pfd = NOTOK;		/* fd to write annotation list to        */
+static uid_t myuid= -1;		/* my user id                            */
+static gid_t mygid= -1;		/* my group id                           */
+static int recipients = 0;	/* how many people will get a copy       */
+static int unkadr = 0;		/* how many of those were unknown        */
+static int badadr = 0;		/* number of bad addrs                   */
+static int badmsg = 0;		/* message has bad semantics             */
+static int verbose = 0;		/* spell it out                          */
+static int format = 1;		/* format addresses                      */
+static int mime = 0;		/* use MIME-style encapsulations for Bcc */
+static int msgid = 0;		/* add msgid                             */
+static int debug = 0;		/* debugging post                        */
+static int watch = 0;		/* watch the delivery process            */
+static int whomsw = 0;		/* we are whom not post                  */
+static int checksw = 0;		/* whom -check                           */
+static int linepos=0;		/* putadr()'s position on the line       */
+static int nameoutput=0;	/* putadr() has output header name       */
 
 static unsigned msgflags = 0;	/* what we've seen */
 
@@ -369,11 +368,10 @@ main (int argc, char **argv)
     invo_name = r1bindex (argv[0], '/');
     m_foil (NULL);		/* foil search of use profile */
     mts_init (invo_name);
-#ifdef	MMDFMTS
-#ifdef	MMDFII
+
+#if defined(MMDFMTS) && defined(MMDFII)
     mmdf_init (invo_name);
-#endif	/* MMDFII */
-#endif	/* MMDFMTS */
+#endif /* MMDFMTS and MMDFII */
 
     while ((cp = *argp++)) {
 	if (*cp == '-')
@@ -444,7 +442,7 @@ main (int argc, char **argv)
 		case MIMESW:
 #ifdef MIME
 		    mime++;
-		    filter = 0;
+		    filter = NULL;
 #endif
 		    continue;
 		case NMIMESW: 
@@ -596,6 +594,7 @@ main (int argc, char **argv)
     if (access (msg, R_OK) == NOTOK)
 	adios (msg, "unable to read");
 #endif /* MHMTS */
+
     if ((in = fopen (msg, "r")) == NULL)
 	adios (msg, "unable to open");
 
@@ -704,6 +703,8 @@ daemon: ;
     if (encryptsw)
 	tmastart (tmasnoop);
 #endif /* TMA */
+
+    /* If we are doing a "whom" check */
     if (whomsw) {
 	if (!fill_up)
 	    verify_all_addresses (1);
@@ -753,7 +754,10 @@ daemon: ;
     done (0);
 }
 
-/* DRAFT GENERATION */
+
+/*
+ * DRAFT GENERATION
+ */
 
 static void
 putfmt (char *name, char *str, FILE *out)
@@ -914,9 +918,8 @@ static void
 start_headers (void)
 {
     register char  *cp;
-    char    myhost[BUFSIZ],
-            sigbuf[BUFSIZ];
-    register struct mailname   *mp;
+    char myhost[BUFSIZ], sigbuf[BUFSIZ];
+    register struct mailname *mp;
 
     myuid = getuid ();
     mygid = getgid ();
@@ -946,9 +949,9 @@ start_headers (void)
 	mnfree (mp);
 	while (getname (""))
 	    continue;
-    }
-    else
+    } else {
 	strcpy (signature, adrsprintf (NULL, NULL));
+    }
 }
 
 
@@ -960,7 +963,7 @@ finish_headers (FILE *out)
 	    if (whomsw && !fill_up)
 		break;
 
-	    fprintf (out, "Date: %s\n", dtime (&tclock));
+	    fprintf (out, "Date: %s\n", dtime (&tclock, 0));
 	    if (msgid)
 		fprintf (out, "Message-ID: <%d.%ld@%s>\n",
 			getpid (), tclock, LocalName ());
@@ -991,7 +994,7 @@ finish_headers (FILE *out)
 	    fprintf (out, "Sender: %s\n", from);
 #endif /* MMDFI */
 
-	    fprintf (out, "Resent-Date: %s\n", dtime (&tclock));
+	    fprintf (out, "Resent-Date: %s\n", dtime (&tclock, 0));
 	    if (msgid)
 		fprintf (out, "Resent-Message-ID: <%d.%ld@%s>\n",
 			getpid (), tclock, LocalName ());
@@ -1131,7 +1134,7 @@ insert (struct mailname *np)
 static void
 pl (void)
 {
-    register int     i;
+    register int i;
     register struct mailname *mp;
 
     printf ("-------\n\t-- Addresses --\nlocal:\t");
@@ -1232,7 +1235,7 @@ make_bcc_file (void)
 	adios (bccfil, "unable to create");
     chmod (bccfil, 0600);
 
-    fprintf (out, "Date: %s\n", dtime (&tclock));
+    fprintf (out, "Date: %s\n", dtime (&tclock, 0));
     if (msgid)
 	fprintf (out, "Message-ID: <%d.%ld@%s>\n",
 		getpid (), tclock, LocalName ());
@@ -1240,7 +1243,11 @@ make_bcc_file (void)
     if (subject)
 	fprintf (out, "Subject: %s", subject);
     fprintf (out, "BCC:\n");
+
 #ifdef MIME
+    /*
+     * Use MIME encapsulation for Bcc messages
+     */
     if (mime) {
 	char *cp;
 
@@ -1251,8 +1258,7 @@ make_bcc_file (void)
 		(*cp)++;
 	    else
 		if (*++cp == 0)
-		    adios (NULL,
-			   "giving up trying to find a unique delimiter string");
+		    adios (NULL, "can't find a unique delimiter string");
 		else
 		    (*cp)++;
 
@@ -1262,19 +1268,14 @@ make_bcc_file (void)
     } else
 #endif /* MIME */
 	fprintf (out, "\n------- Blind-Carbon-Copy\n\n");
+
     fflush (out);
 
-    if (filter == NULL) {
-	if ((fd = open (tmpfil, 0)) == NOTOK)
-	    adios (tmpfil, "unable to re-open");
-#ifdef MIME
-	if (mime)
-	    cpydata (fd, fileno (out), tmpfil, bccfil);
-	else
-#endif /* MIME */
-	    cpydgst (fd, fileno (out), tmpfil, bccfil);
-	close (fd);
-    } else {
+    /*
+     * Do mhl filtering of Bcc messages instead
+     * of MIME encapsulation.
+     */
+    if (filter != NULL) {
 	vec[0] = r1bindex (mhlproc, '/');
 
 	for (i = 0; (child_id = fork()) == NOTOK && i < 5; i++)
@@ -1302,9 +1303,19 @@ make_bcc_file (void)
 		pidXwait (child_id, mhlproc);
 		break;
 	}
+    } else {
+	if ((fd = open (tmpfil, O_RDONLY)) == NOTOK)
+	    adios (tmpfil, "unable to re-open");
+#ifdef MIME
+	if (mime)
+	    cpydata (fd, fileno (out), tmpfil, bccfil);
+	else
+#endif /* MIME */
+	    cpydgst (fd, fileno (out), tmpfil, bccfil);
+	close (fd);
     }
 
-    fseek (out, 0L, 2);
+    fseek (out, 0L, SEEK_END);
 #ifdef MIME
     if (mime)
 	fprintf (out, "\n--%s--\n", prefix);
@@ -1349,7 +1360,10 @@ find_prefix (void)
 }
 #endif /* MIME */
 
-/* ADDRESS VERIFICATION */
+
+/*
+ * ADDRESS VERIFICATION
+ */
 
 static void
 verify_all_addresses (int talk)
@@ -1378,17 +1392,16 @@ verify_all_addresses (int talk)
 		    rp_valstr (retval));
 #ifdef RP_NS
 	if (rp_isbad (retval = mm_rrply (&reply, &len)))
-	    die (NULL, "problem with sender address [%s]",
-		    rp_valstr (retval));
+	    die (NULL, "problem with sender address [%s]", rp_valstr (retval));
 #endif /* RP_NS */
     }
 #endif /* MMDFMTS */
+
 #ifdef SENDMTS
     if (!whomsw || checksw)
 	if (rp_isbad (retval = sm_init (clientsw, serversw, 0, 0, snoop, 0, 0))
 		|| rp_isbad (retval = sm_winit (smtpmode, from)))
-	    die (NULL, "problem initializing server; %s",
-		    rp_string (retval));
+	    die (NULL, "problem initializing server; %s", rp_string (retval));
 #endif /* SENDMTS */
 
     if (talk && !whomsw)
@@ -1503,11 +1516,11 @@ post (char *file, int bccque, int talk)
 
 #ifndef	MHMTS
     do_addresses (bccque, talk && verbose);
-    if ((fd = open (file, 0)) == NOTOK)
+    if ((fd = open (file, O_RDONLY)) == NOTOK)
 	die (file, "unable to re-open");
     do_text (file, fd);
 #else /* MHMTS */
-    if ((fd = open (file, 0)) == NULL)
+    if ((fd = open (file, O_RDONLY)) == NULL)
 	adios (file, "unable to re-open");
 #ifdef MF
     ud = UucpChan () && uuaddrs.m_next ? make_uucp_file (fd) : NOTOK;
@@ -1556,7 +1569,7 @@ postcipher (char *file, int bccque, int talk)
 	else
 	    printf (" -- Posting for All Recipients --\n");
 
-    if ((fdP = open (file, 0)) == NOTOK)
+    if ((fdP = open (file, O_RDONLY)) == NOTOK)
 	adios (file, "unable to re-open");
     if (ciphinit (fdP, reason) == NOTOK)
 	adios (NULL, "%s", reason);
@@ -1796,9 +1809,8 @@ do_addresses (char *file, int fd, int ud, int bccque, int talk)
 static void
 do_text (char *file, int fd)
 {
-    int     retval,
-            state;
-    char    buf[BUFSIZ];
+    int retval, state;
+    char buf[BUFSIZ];
 #ifdef	MMDFMTS
     struct rp_bufstruct reply;
 #endif	/* MMDFMTS */
@@ -1863,7 +1875,10 @@ do_text (char *file, int fd)
 }
 #endif	/* not MHMTS */
 
-/* MTS-SPECIFIC INTERACTION */
+
+/*
+ * MTS-SPECIFIC INTERACTION
+ */
 
 #ifdef MMDFMTS
 
@@ -2321,9 +2336,9 @@ die (char *what, char *fmt, ...)
 
 #ifdef MMDFMTS
 /* 
- *    err_abrt() is used by the mm_ routines
- *    		 do not, under *ANY* circumstances, remove it from post,
- *		 or you will lose *BIG*
+ * err_abrt() is used by the mm_ routines
+ *    	 do not, under *ANY* circumstances, remove it from post,
+ *	 or you will lose *BIG*
  */
 
 void
@@ -2342,7 +2357,10 @@ err_abrt (int code, char *fmt, ...)
 }
 #endif	/* MMDFMTS */
 
-/* STAND-ALONE DELIVERY */
+
+/*
+ * STAND-ALONE DELIVERY
+ */
 
 #ifdef MHMTS
 
@@ -2396,7 +2414,7 @@ localmail (struct mailname *lp, int talk, int fd)
 		unkadr++;
 		return;
 	    }
-	    sprintf (ddate, "Delivery-Date: %s\n", dtimenow ());
+	    sprintf (ddate, "Delivery-Date: %s\n", dtimenow (0));
 	    if (mbx_copy (mailbox, md, fd, 0, ddate, 0) == NOTOK) {
 		if (!talk)
 		    fprintf (stderr, "  %s: ", lp->m_mbox);
@@ -2454,7 +2472,7 @@ usr_hook (struct mailname *lp, int talk, int fd, struct home *hp, char *mailbox)
 		dup2 (fd, 3);
 	    closefds (4);
 #ifdef TIOCNOTTY
-	    if ((fd = open ("/dev/tty", 2)) != NOTOK) {
+	    if ((fd = open ("/dev/tty", O_RDWR)) != NOTOK) {
 		ioctl (fd, TIOCNOTTY, NULL);
 		close (fd);
 	    }
