@@ -6,6 +6,7 @@
  */
 
 #include <h/mh.h>
+#include <fcntl.h>
 #include <h/signals.h>
 #include <errno.h>
 #include <signal.h>
@@ -373,7 +374,7 @@ no_body: ;
 #endif
     }
 
-    if ((fdi = open (tmpfil, 0)) == NOTOK)
+    if ((fdi = open (tmpfil, O_RDONLY)) == NOTOK)
 	adios (tmpfil, "unable to re-open");
     if ((fdo = creat (drft, m_gmprot ())) == NOTOK)
 	adios (drft, "unable to write");
