@@ -89,7 +89,7 @@ main (int argc, char **argv)
     if ((fp = fopen (tmpfil, "w+")) == NULL)
 	adios (tmpfil, "unable to create");
     cpydata (fileno (stdin), fileno (fp), "message", tmpfil);
-    fseek (fp, 0L, 0);
+    fseek (fp, 0L, SEEK_SET);
     strcpy (drft, m_tmpfil (invo_name));
     rcvdistout (fp, form, addrs);
     fclose (fp);
