@@ -36,6 +36,11 @@ extern int errno;
 
 static char *tmpfilenam = NULL;
 
+/*
+ * prototypes
+ */
+static int folder_addmsg(struct msgs *, char *);
+
 
 main (int argc, char **argv)
 {
@@ -54,9 +59,9 @@ main (int argc, char **argv)
     if ((cp = m_find (invo_name))) {
 	ap = brkstring (cp = getcpy (cp), " ", "\n");
 	ap = copyip (ap, arguments);
-    }
-    else
+    } else {
 	ap = arguments;
+    }
     copyip (argv + 1, ap);
     argp = arguments;
 
@@ -116,6 +121,8 @@ main (int argc, char **argv)
 	    adios (NULL, "usage: %s [+folder] [switches]", invo_name);
     }
 
+    seqs[seqp] = NULL;	/* NULL terminate list of sequences */
+
     if (!m_find ("path"))
 	free (path ("./", TFOLDER));
     if (!folder && !(folder = m_find (inbox)))
@@ -135,7 +142,7 @@ main (int argc, char **argv)
 	adios (maildir, "unable to change directory to");
 
     /* read folder and create message structure */
-    if (!(mp = m_gmsg (folder)))
+    if (!(mp = m_readfolder (folder)))
 	adios (NULL, "unable to read folder %s", folder);
 
     SIGNAL (SIGHUP, SIG_IGN);
@@ -163,43 +170,69 @@ main (int argc, char **argv)
 	done (0);
     }
 
+    /* Link message into folder */
+    if ((msgnum = folder_addmsg(mp, tmpfilenam)) == -1)
+	done (1);
+
+    unlink (tmpfilenam);
+    tmpfilenam = NULL;
+
+    /* add the message to all the specified sequences */
+    for (seqp = 0; seqs[seqp]; seqp++) {
+	if (!seq_addmsg (mp, seqs[seqp], msgnum, publicsw, zerosw))
+	    done (1);
+    }
+
+    seq_setunseen (mp, 0);	/* add message to the Unseen-Sequence */
+    seq_save (mp);		/* synchronize message sequences      */
+    m_freefolder (mp);		/* free folder/message structure      */
+    m_update ();		/* update the context file            */
+    done (0);
+}
+
+
+/*
+ * Link message into a folder.  Set the EXISTS and
+ * UNSEEN bits.  Return the new number of the message.
+ * If an error, return -1;
+ */
+static int
+folder_addmsg(struct msgs *mp, char *msgfile)
+{
+    int msgnum;
+
     msgnum = mp->hghmsg;
     do {
 	msgnum++;
 	mp->hghmsg++;
-	if (msgnum > mp->hghoff)
-	    if (!(mp = m_remsg (mp, 0, mp->hghoff + MAXFOLDER)))
-		adios (NULL, "unable to allocate folder storage");
+	if (msgnum > mp->hghoff) {
+	    if (!(mp = m_remsg (mp, 0, mp->hghoff + MAXFOLDER))) {
+		advise (NULL, "unable to allocate folder storage");
+		return -1;
+	    }
+	}
 
 	set_exists (mp, msgnum);
 	set_unseen (mp, msgnum);
 	errno = 0;
-    } while (link (tmpfilenam, m_name (msgnum)) == NOTOK && errno == EEXIST);
+    } while (link (msgfile, m_name (msgnum)) == NOTOK && errno == EEXIST);
 
-    unlink (tmpfilenam);
-    tmpfilenam = NULL;
-    if (errno != 0)
-	adios (NULL, "can't file message %d", msgnum);
+    if (errno != 0) {
+	advise (NULL, "can't file message %d", msgnum);
+	return -1;
+    }
 
     if (mp->lowmsg == 0)
 	mp->lowmsg = msgnum;
     mp->msgflags |= SEQMOD;
 
-    seqs[seqp] = NULL;
-    for (seqp = 0; seqs[seqp]; seqp++) {
-	if (zerosw && !m_seqnew (mp, seqs[seqp], publicsw))
-	    done (1);
-	if (!m_seqadd (mp, seqs[seqp], msgnum, publicsw))
-	    done (1);
-    }
-
-    m_setvis (mp, 0);	/* set the unseen sequence       */
-    m_sync (mp);	/* synchronize message sequences */
-    m_fmsg (mp);	/* free folder/message structure */
-    m_update ();	/* update the context file       */
-    done (0);
+    return msgnum;
 }
 
+
+/*
+ * Clean up and exit
+ */
 void
 done(int status)
 {
