@@ -36,17 +36,19 @@ static struct swit switches[] = {
     { "form formatfile", 0 },
 #define	FMTSW	2
     { "format string", 5 },
-#define NLSW    3
+#define WIDTHSW 3
+    { "width columns", 0 },
+#define NLSW    4
     { "newline", 0 },
-#define NNLSW   4
+#define NNLSW   5
     { "nonewline", 0 },
-#define BELSW	5
+#define BELSW	6
     { "bell", 0 },
-#define	NBELSW	6
+#define	NBELSW	7
     { "nobell", 0 },
-#define VERSIONSW 7
+#define VERSIONSW 8
     { "version", 0 },
-#define	HELPSW	8
+#define	HELPSW	9
     { "help", 4 },
     { NULL, 0 }
 };
@@ -55,6 +57,7 @@ static jmp_buf myctx;
 static int bell = 1;
 static int newline = 1;
 static int biff = 0;
+static int width = 0;
 static char *form = NULL;
 static char *format = NULL;
 
@@ -127,6 +130,11 @@ main (int argc, char **argv)
 		    form = NULL;
 		    continue;
 
+		case WIDTHSW:
+		    if (!(cp = *argp++) || *cp == '-')
+			adios(NULL, "missing argument to %s", argp[-2]);
+		    width = atoi(cp);
+		    continue;
                 case NLSW:
                     newline = 1;
                     continue;
@@ -231,7 +239,7 @@ static int
 header_fd (void)
 {
     int fd;
-    char tmpfil[BUFSIZ];
+    char *nfs, tmpfil[BUFSIZ];
 
     strcpy (tmpfil, m_tmpfil (invo_name));
     if ((fd = open (tmpfil, O_RDWR | O_CREAT | O_TRUNC, 0600)) == NOTOK)
@@ -239,7 +247,8 @@ header_fd (void)
     unlink (tmpfil);
 
     rewind (stdin);
-    scan (stdin, 0, 0, new_fs (form, format, SCANFMT), 0, 0, 0, 0, 0L, 0);
+    nfs = new_fs (form, format, SCANFMT);
+    scan (stdin, 0, 0, nfs, width, 0, 0, 0, 0L, 0);
     if (newline)
         write (fd, "\n\r", 2);
     write (fd, scanl, strlen (scanl));
@@ -272,7 +281,7 @@ alert (char *tty, int md)
     if (!setjmp (myctx)) {
 	SIGNAL (SIGALRM, alrmser);
 	alarm (2);
-	td = open (ttyspec, 1);
+	td = open (ttyspec, O_WRONLY);
 	alarm (0);
 	if (td == NOTOK)
 	    return;
@@ -302,7 +311,7 @@ alert (char *user, int md)
 	return;
     SIGNAL (SIGPIPE, SIG_IGN);
 
-    lseek (md, (off_t), SEEK_SET);
+    lseek (md, (off_t) 0, SEEK_SET);
     while ((i = read (md, buffer, sizeof(buffer))) > 0)
 	if (write (td, buffer, i) != i)
 	    break;
