@@ -7,6 +7,7 @@
  */
 
 #include <h/mh.h>
+#include <fcntl.h>
 #include <errno.h>
 
 static struct swit switches[] = {
@@ -35,7 +36,7 @@ static struct swit switches[] = {
     { NULL, 0 }
 };
 
-extern int  errno;
+extern int errno;
 
 static char maildir[BUFSIZ];
 
@@ -49,19 +50,20 @@ struct st_fold {
  */
 static void opnfolds (struct st_fold *, int);
 static void clsfolds (struct st_fold *, int);
-static void removeit (struct msgs *, int, char **);
+static void remove_files (int, char **);
 static int m_file (char *, struct st_fold *, int, int);
+static int addmsg (struct msgs **, char *, int);
 
 
 main (int argc, char **argv)
 {
-    int	linkf = 0, prsrvf = 0, filep = 0;
+    int	linkf = 0, preserve = 0, filep = 0;
     int foldp = 0, msgp = 0, isdf = 0;
     int i, msgnum;
     char *cp, *folder = NULL, buf[100];
     char **ap, **argp, *arguments[MAXARGS];
     char *filevec[NFOLDERS + 2];
-    char **files = &filevec[1];		/* leave room for removeit:vec[0] */
+    char **files = &filevec[1];	   /* leave room for remove_files:vec[0] */
     char *msgs[MAXARGS];
     struct st_fold folders[NFOLDERS + 1];
     struct msgs *mp;
@@ -104,10 +106,10 @@ main (int argc, char **argv)
 		    continue;
 
 		case PRESSW: 
-		    prsrvf++;
+		    preserve++;
 		    continue;
 		case NPRESSW: 
-		    prsrvf = 0;
+		    preserve = 0;
 		    continue;
 
 		case SRCSW: 
@@ -145,9 +147,9 @@ main (int argc, char **argv)
 		adios (NULL, "only %d folders allowed!", NFOLDERS);
 	    folders[foldp++].f_name =
 		    path (cp + 1, *cp == '+' ? TFOLDER : TSUBCWF);
-	}
-	else
+	} else {
 	    msgs[msgp++] = cp;
+	}
     }
 
     if (!m_find ("path"))
@@ -165,10 +167,11 @@ main (int argc, char **argv)
 	    adios (NULL, "use -file or some messages, not both");
 	opnfolds (folders, foldp);
 	for (i = 0; i < filep; i++)
-	    if (m_file (files[i], folders, foldp, prsrvf))
+	    if (m_file (files[i], folders, foldp, preserve))
 		done (1);
+	/* If -nolink, then "remove" files */
 	if (!linkf)
-	    removeit (NULLMP, filep, filevec);
+	    remove_files (filep, filevec);
 	done (0);
     }
 
@@ -180,7 +183,9 @@ main (int argc, char **argv)
 
     if (chdir (maildir) == NOTOK)
 	adios (maildir, "unable to change directory to");
-    if (!(mp = m_gmsg (folder)))
+
+    /* read source folder */
+    if (!(mp = m_readfolder (folder)))
 	adios (NULL, "unable to read folder %s", folder);
     if (mp->hghmsg == 0)
 	adios (NULL, "no messages in %s", folder);
@@ -189,40 +194,44 @@ main (int argc, char **argv)
     for (msgnum = 0; msgnum < msgp; msgnum++)
 	if (!m_convert (mp, msgs[msgnum]))
 	    done (1);
-    m_setseq (mp);	/* set the previous-sequence */
+    seq_setprev (mp);	/* set the previous-sequence */
 
+    /* create folder structures for each destination folder */
     opnfolds (folders, foldp);
-    for (msgnum = mp->lowsel; msgnum <= mp->hghsel; msgnum++)
+
+    /* Link all the selected messages into destination folders */
+    for (msgnum = mp->lowsel; msgnum <= mp->hghsel; msgnum++) {
 	if (is_selected (mp, msgnum)) {
 	    cp = getcpy (m_name (msgnum));
-	    if (m_file (cp, folders, foldp, prsrvf))
+	    if (m_file (cp, folders, foldp, preserve))
 		done (1);
 	    free (cp);
-	    if (!linkf) {
-#ifdef notdef
-		mp->msgstats[msgnum] |= DELETED;
-#endif /* notdef */
-		mp->msgstats[msgnum] &= ~EXISTS;
-	    }
 	}
-    if (!linkf)
-	mp->msgflags |= SEQMOD;
+    }
+
+    /* If -nolink, then "remove" messages from source folder */
+    if (!linkf) {
+	folder_delmsgs (mp, 0);
+    }
+
     clsfolds (folders, foldp);
 
-    m_replace (pfolder, folder);	/* update current folder */
     if (mp->hghsel != mp->curmsg
 	    && (mp->numsel != mp->nummsg || linkf))
-	m_setcur (mp, mp->hghsel);
-    m_sync (mp);
-    m_update ();	/* update the context file */
-
-    if (!linkf)
-	removeit (mp, filep, filevec);
+	seq_setcur (mp, mp->hghsel);
+    seq_save (mp);	/* synchronize message sequences */
 
+    m_replace (pfolder, folder);	/* update current folder   */
+    m_update ();			/* update the context file */
     done (0);
 }
 
 
+/*
+ * Read all the destination folders and
+ * create folder structures for all of them.
+ */
+
 static void
 opnfolds (struct st_fold *folders, int nfolders)
 {
@@ -232,7 +241,7 @@ opnfolds (struct st_fold *folders, int nfolders)
     register struct msgs *mp;
     struct stat st;
 
-    for (ep = (fp = folders) + nfolders; fp < ep; fp++) {
+    for (fp = folders, ep = folders + nfolders; fp < ep; fp++) {
 	chdir (m_maildir (""));
 	strcpy (nmaildir, m_maildir (fp->f_name));
 
@@ -249,7 +258,7 @@ opnfolds (struct st_fold *folders, int nfolders)
 
 	if (chdir (nmaildir) == NOTOK)
 	    adios (nmaildir, "unable to change directory to");
-	if (!(mp = m_gmsg (fp->f_name)))
+	if (!(mp = m_readfolder (fp->f_name)))
 	    adios (NULL, "unable to read folder %s", fp->f_name);
 	mp->curmsg = 0;
 
@@ -260,43 +269,41 @@ opnfolds (struct st_fold *folders, int nfolders)
 }
 
 
+/*
+ * Set the Previous-Sequence and then sychronize the
+ * sequence file, for each destination folder.
+ */
+
 static void
 clsfolds (struct st_fold *folders, int nfolders)
 {
     register struct st_fold *fp, *ep;
     register struct msgs *mp;
 
-    for (ep = (fp = folders) + nfolders; fp < ep; fp++) {
+    for (fp = folders, ep = folders + nfolders; fp < ep; fp++) {
 	mp = fp->f_mp;
-	m_setseq (mp);
-	m_sync (mp);
+	seq_setprev (mp);
+	seq_save (mp);
     }
 }
 
 
-static void
-removeit (struct msgs *mp, int filep, char **files)
-{
-    register int i, vecp;
-    register char *cp, **vec;
+/*
+ * If you have a "rmmproc" defined, we called that
+ * to remove all the specified files.  If "rmmproc"
+ * is not defined, then just unlink the files.
+ */
 
+static void
+remove_files (int filep, char **files)
+{
+    int i;
+    char **vec;
+
+    /* If rmmproc is defined, we use that */
     if (rmmproc) {
-	if (filep > 0) {
-	    vec = files++;	/* filevec[1] */
-	    files[filep] = NULL;
-	} else {
-	    if (mp->numsel > MAXARGS - 2)
-		adios (NULL, "more than %d messages for %s exec",
-			MAXARGS - 2, rmmproc);
-	    vec = (char **) calloc ((size_t) (mp->numsel + 2), sizeof *vec);
-	    if (vec == NULL)
-		adios (NULL, "unable to allocate exec vector");
-	    vecp = 1;
-	    for (i = mp->lowsel; i <= mp->hghsel; i++)
-		if (is_selected (mp, i))
-		    vec[vecp++] = getcpy (m_name (i));
-	    vec[vecp] = NULL;
-	}
+	vec = files++;		/* vec[0] = filevec[0] */
+	files[filep] = NULL;	/* NULL terminate list */
 
 	fflush (stdout);
 	vec[0] = r1bindex (rmmproc, '/');
@@ -304,109 +311,151 @@ removeit (struct msgs *mp, int filep, char **files)
 	adios (rmmproc, "unable to exec");
     }
 
-    if (filep > 0) {
-	files++;	/* filevec[1] */
-	for (i = 0; i < filep; i++)
-	    if (unlink (files[i]) == NOTOK)
-		admonish (files[i], "unable to unlink");
-    } else {
-	for (i = mp->lowsel; i <= mp->hghsel; i++)
-	    if (is_selected (mp, i))
-		if (unlink (cp = m_name (i)) == NOTOK)
-		    admonish (cp, "unable to unlink");
+    /* Else just unlink the files */
+    files++;	/* advance past filevec[0] */
+    for (i = 0; i < filep; i++) {
+	if (unlink (files[i]) == NOTOK)
+	    admonish (files[i], "unable to unlink");
     }
 }
 
 
+/*
+ * Link (or copy) the message into each of
+ * the destiniation folders.
+ */
+
 static int
-m_file (char *msg, struct st_fold *folders, int nfolders, int prsrvf)
+m_file (char *msgfile, struct st_fold *folders, int nfolders, int preserve)
+{
+    struct st_fold *fp, *ep;
+
+    for (fp = folders, ep = folders + nfolders; fp < ep; fp++) {
+	if (addmsg (&fp->f_mp, msgfile, preserve))
+	    return 1;
+    }
+    return 0;
+}
+
+
+/*
+ * Link message into a folder
+ */
+
+static int
+addmsg (struct msgs **mpp, char *msgfile, int preserve)
 {
     int in, out, linkerr, msgnum;
-    register char *nmsg;
-    char newmsg[BUFSIZ];
-    register struct st_fold *fp, *ep;
-    register struct msgs *mp;
-    struct stat st, s1;
+    char *nmsg, newmsg[BUFSIZ];
+    struct msgs *mp;
+    struct stat st1, st2;
 
-    for (ep = (fp = folders) + nfolders; fp < ep; fp++) {
-	mp = fp->f_mp;
-	if (prsrvf && (msgnum = m_atoi (nmsg = msg)) > 0) {
-	    if (msgnum >= mp->hghoff)
-		if ((mp = m_remsg (mp, 0, msgnum + MAXFOLDER)))
-		    fp->f_mp = mp;
-		else
-		    adios (NULL, "unable to allocate folder storage");
-	    if (!(mp->msgstats[msgnum] & EXISTS)) {
-		mp->msgstats[msgnum] |= EXISTS;
-#ifdef notdef
-		mp->msgstats[msgnum] &= ~DELETED;
-#endif /* notdef */
-		mp->nummsg++;
-	    }
-	    set_selected (mp, msgnum);
-	    if (msgnum > mp->hghmsg)
-		mp->hghmsg = msgnum;
+    mp = *mpp;
+
+    /* Preserve the numbering of the message */
+    if (preserve && (msgnum = m_atoi (msgfile)) > 0) {
+	nmsg = msgfile;
+	if (msgnum >= mp->hghoff) {
+	    if ((mp = m_remsg (mp, 0, msgnum + MAXFOLDER)))
+		*mpp = mp;
+	    else
+		adios (NULL, "unable to allocate folder storage");
 	}
-	else {
-	    if (mp->hghmsg >= mp->hghoff)
-		if ((mp = m_remsg (mp, 0, mp->hghoff + MAXFOLDER)))
-		    fp->f_mp = mp;
-		else
-		    adios (NULL, "unable to allocate folder storage");
-
-	    nmsg = m_name (msgnum = ++mp->hghmsg);
-	    mp->nummsg++;
+	if (!(mp->msgstats[msgnum] & EXISTS)) {
 	    mp->msgstats[msgnum] |= EXISTS;
-	    set_selected (mp, msgnum);
+#if 0
+	    mp->msgstats[msgnum] &= ~DELETED;
+#endif
+	    mp->nummsg++;
+	}
+	set_selected (mp, msgnum);
+	if (msgnum > mp->hghmsg)
+	    mp->hghmsg = msgnum;
+    } else {
+	/* Else assign it next highest number available */
+	if (mp->hghmsg >= mp->hghoff) {
+	    if ((mp = m_remsg (mp, 0, mp->hghoff + MAXFOLDER)))
+		*mpp = mp;
+	    else
+		adios (NULL, "unable to allocate folder storage");
 	}
-	if (mp->lowmsg == 0)
-	    mp->lowmsg = msgnum;
-	if (mp->lowsel == 0 || msgnum < mp->lowsel)
-	    mp->lowsel = msgnum;
-	if (msgnum > mp->hghsel)
-	    mp->hghsel = msgnum;
 
-	sprintf (newmsg, "%s/%s", mp->foldpath, nmsg);
-	if (link (msg, newmsg) == NOTOK) {
-#ifndef	EISREMOTE
-	    linkerr = errno;
-#else /* EISREMOTE */
-	    if ((linkerr = errno) == EISREMOTE)
-		linkerr = EXDEV;
+	msgnum = ++mp->hghmsg;	/* get next number available */
+	nmsg = m_name (msgnum);
+	mp->nummsg++;
+	mp->msgstats[msgnum] |= EXISTS;
+	set_selected (mp, msgnum);
+    }
+
+    if (mp->lowmsg == 0)
+	mp->lowmsg = msgnum;
+    if (mp->lowsel == 0 || msgnum < mp->lowsel)
+	mp->lowsel = msgnum;
+    if (msgnum > mp->hghsel)
+	mp->hghsel = msgnum;
+
+    sprintf (newmsg, "%s/%s", mp->foldpath, nmsg);
+
+    /*
+     * Now link message into new folder
+     */
+    if (link (msgfile, newmsg) == NOTOK) {
+	linkerr = errno;
+
+#ifdef EISREMOTE
+	if (linkerr == EISREMOTE)
+	    linkerr = EXDEV;
 #endif /* EISREMOTE */
-	    if (linkerr == EEXIST
-		    || (linkerr == EXDEV && stat (newmsg, &st) != NOTOK)) {
-		if (linkerr != EEXIST
-			|| stat (msg, &s1) == NOTOK
-			|| stat (newmsg, &st) == NOTOK
-			|| s1.st_ino != st.st_ino) {
-		    advise (NULL, "message %s:%s already exists",
-			    fp->f_name, newmsg);
-		    return 1;
-		}
-		continue;
+
+	/*
+	 * Check if the file in our desired location is the
+	 * same as the source file.  If so, then just continue,
+	 * else print error message and return.
+	 */
+	if (linkerr == EEXIST) {
+	    if (stat (msgfile, &st2) == OK && stat (newmsg, &st1) == OK
+		&& st2.st_ino == st1.st_ino) {
+		return 0;
+	    } else {
+		advise (NULL, "message %s already exists", newmsg);
+		return 1;
 	    }
-	    if (linkerr == EXDEV) {
-		if ((in = open (msg, 0)) == NOTOK) {
-		    advise (msg, "unable to open message %s");
+	}
+
+	/*
+	 * If link failed because we are trying to link
+	 * across devices, then check if there is a message
+	 * already in the desired location.  If so, then return
+	 * error, else just copy the message.
+	 */
+	if (linkerr == EXDEV) {
+	    if (stat (newmsg, &st1) == OK) {
+		advise (NULL, "message %s:%s already exists", newmsg);
+		return 1;
+	    } else {
+		if ((in = open (msgfile, O_RDONLY)) == NOTOK) {
+		    advise (msgfile, "unable to open message %s");
 		    return 1;
 		}
-		fstat (in, &st);
-		if ((out = creat (newmsg, (int) st.st_mode & 0777))
-			== NOTOK) {
+		fstat (in, &st1);
+		if ((out = creat (newmsg, (int) st1.st_mode & 0777)) == NOTOK) {
 		    advise (newmsg, "unable to create");
 		    close (in);
 		    return 1;
 		}
-		cpydata (in, out, msg, newmsg);
+		cpydata (in, out, msgfile, newmsg);
 		close (in);
 		close (out);
-	    }
-	    else {
-		advise (newmsg, "error linking %s to", msg);
-		return 1;
+		return 0;
 	    }
 	}
+
+	/*
+	 * Else, some other type of link error,
+	 * so just return error.
+	 */
+	advise (newmsg, "error linking %s to", msgfile);
+	return 1;
     }
 
     return 0;
