@@ -379,7 +379,7 @@ try_it_again: ;
 	adios (maildir, "unable to change directory to");
 
     /* read folder and create message structure */
-    if (!(mp = m_gmsg (folder)))
+    if (!(mp = m_readfolder (folder)))
 	adios (NULL, "unable to read folder %s", folder);
 
     if (mp->hghmsg == 0)
@@ -388,15 +388,15 @@ try_it_again: ;
     /* parse the message range/sequence/name and set SELECTED */
     if (!m_convert (mp, msg))
 	done (1);
-    m_setseq (mp);	/* set the previous-sequence */
+    seq_setprev (mp);	/* set the previous-sequence */
 
     if (mp->numsel > 1)
 	adios (NULL, "only one message at a time!");
 
     m_replace (pfolder, folder);	/* update current folder */
     if (mp->lowsel != mp->curmsg)
-	m_setcur (mp, mp->lowsel);
-    m_sync (mp);
+	seq_setcur (mp, mp->lowsel);
+    seq_save (mp);
     m_update ();			/* update the context file */
 
 go_to_it: ;
