@@ -39,9 +39,9 @@ main (int argc, char **argv)
     if ((cp = m_find (invo_name)) != NULL) {
 	ap = brkstring (cp = getcpy (cp), " ", "\n");
 	ap = copyip (ap, arguments);
-    }
-    else
+    } else {
 	ap = arguments;
+    }
     copyip (argv + 1, ap);
     argp = arguments;
 
@@ -195,6 +195,11 @@ rmf (char *folder)
 }
 
 
+/*
+ * Remove any private sequences or attributes
+ * for this folder from the context.
+ */
+
 static void
 rma (char *folder)
 {
@@ -206,7 +211,7 @@ rma (char *folder)
     plen = strlen (cp = m_mailpath (folder)) + 1;
 
     m_getdefs ();
-    for (np = m_defs, pp = NULL; np; np = np->n_next)
+    for (np = m_defs, pp = NULL; np; np = np->n_next) {
 	if (ssequal ("atr-", np->n_name)
 		&& (j = strlen (np->n_name) - plen) > alen
 		&& *(np->n_name + j) == '-'
@@ -220,7 +225,8 @@ rma (char *folder)
 	    else
 		m_defs = np->n_next;
 	    ctxflags |= CTXMOD;
-	}
-	else
+	} else {
 	    pp = np;
+	}
+    }
 }
