@@ -18,9 +18,9 @@ static struct swit switches[] = {
 
 main (int argc, char **argv)
 {
-    int msgp = 0, msgnum, vecp;
-    char *cp, *dp, *maildir, *folder = NULL;
-    char buf[100], **ap, **argp, **vec;
+    int msgp = 0, msgnum;
+    char *cp, *maildir, *folder = NULL;
+    char buf[100], **ap, **argp;
     char *arguments[MAXARGS], *msgs[MAXARGS];
     struct msgs *mp;
 
@@ -31,9 +31,9 @@ main (int argc, char **argv)
     if ((cp = m_find (invo_name)) != NULL) {
 	ap = brkstring (cp = getcpy (cp), " ", "\n");
 	ap = copyip (ap, arguments);
-    }
-    else
+    } else {
 	ap = arguments;
+    }
     copyip (argv + 1, ap);
     argp = arguments;
 
@@ -76,7 +76,7 @@ main (int argc, char **argv)
 	adios (maildir, "unable to change directory to");
 
     /* read folder and create message structure */
-    if (!(mp = m_gmsg (folder)))
+    if (!(mp = m_readfolder (folder)))
 	adios (NULL, "unable to read folder %s", folder);
 
     if (mp->hghmsg == 0)
@@ -86,49 +86,13 @@ main (int argc, char **argv)
     for (msgnum = 0; msgnum < msgp; msgnum++)
 	if (!m_convert (mp, msgs[msgnum]))
 	    done (1);
-    m_setseq (mp);	/* set the previous-sequence */
+    seq_setprev (mp);		/* set the previous-sequence      */
 
-    for (msgnum = mp->lowsel; msgnum <= mp->hghsel; msgnum++) {
-	if (is_selected (mp, msgnum)) {
-#ifdef notdef
-	    mp->msgstats[msgnum] |= DELETED;
-#endif	/* notdef */
-	    mp->msgstats[msgnum] &= ~EXISTS;
-	}
-    }
-    mp->msgflags |= SEQMOD;
+    folder_delmsgs (mp, 1);	/* "remove" the SELECTED messages */
 
+    seq_save (mp);		/* synchronize message sequences  */
+    m_freefolder (mp);			/* free folder structure   */
     m_replace (pfolder, folder);	/* update current folder   */
-    m_sync (mp);
     m_update ();			/* update the context file */
-
-    if (rmmproc) {
-	if (mp->numsel > MAXARGS - 2)
-	    adios (NULL, "more than %d messages for %s exec", MAXARGS - 2,
-		    rmmproc);
-	vec = (char **) calloc ((size_t) (mp->numsel + 2), sizeof *vec);
-	if (vec == NULL)
-	    adios (NULL, "unable to allocate exec vector");
-	vecp = 1;
-	for (msgnum = mp->lowsel; msgnum <= mp->hghsel; msgnum++)
-	    if (is_selected (mp, msgnum))
-		vec[vecp++] = getcpy (m_name (msgnum));
-	vec[vecp] = NULL;
-
-	fflush (stdout);
-	vec[0] = r1bindex (rmmproc, '/');
-	execvp (rmmproc, vec);
-	adios (rmmproc, "unable to exec");
-    }
-
-    for (msgnum = mp->lowsel; msgnum <= mp->hghsel; msgnum++) {
-	if (is_selected (mp, msgnum)) {
-	    strcpy (buf, m_backup (dp = m_name (msgnum)));
-	    if (rename (dp, buf) == NOTOK)
-		admonish (buf, "unable to rename %s to", dp);
-	}
-    }
-
-    m_fmsg (mp);		/* free folder/message structure */
     done (0);
 }
