@@ -24,7 +24,7 @@ static struct swit switches[] = {
     { "header", 0 },
 #define	NHEADSW	5
     { "noheader", 0 },
-#define	WIDSW	6
+#define	WIDTHSW	6
     { "width columns", 0 },
 #define	REVSW	7
     { "reverse", 0 },
@@ -57,10 +57,9 @@ void clear_screen(void);  /* from termsbr.c */
 main (int argc, char **argv)
 {
     int clearflag = 0, hdrflag = 0, ontty;
-    int state, width = 0, msgp = 0, msgnum;
-    int revflag = 0; 		/* used to be #ifdef BERK */
-    int bits;			/* should match mp->msgstats[] type */
-    time_t clock;
+    int width = 0, msgp = 0, revflag = 0;
+    int i, state, msgnum;
+    int seqnum[NUMATTRS], unseen, num_unseen_seq = 0;
     char *cp, *maildir, *file = NULL, *folder = NULL;
     char *form = NULL, *format = NULL, buf[100], **ap;
     char **argp, *nfs, *arguments[MAXARGS], *msgs[MAXARGS];
@@ -123,7 +122,7 @@ main (int argc, char **argv)
 		    hdrflag = 0;
 		    continue;
 
-		case WIDSW: 
+		case WIDTHSW: 
 		    if (!(cp = *argp++) || *cp == '-')
 			adios (NULL, "missing argument to %s", argp[-2]);
 		    width = atoi (cp);
@@ -152,35 +151,31 @@ main (int argc, char **argv)
 	}
     }
 
-
     if (!m_find ("path"))
 	free (path ("./", TFOLDER));
     nfs = new_fs (form, format, FORMAT);	/* must be before chdir() */
 
+    /*
+     * We are scanning a maildrop file
+     */
     if (file) {
 	if (msgp)
 	    adios (NULL, "\"msgs\" not allowed with -file");
 	if (folder)
 	    adios (NULL, "\"+folder\" not allowed with -file");
 
-	/*
-	 * we've been asked to scan a maildrop file
-	 */
-	if (strcmp (file, "-")) {
-	    in = fopen (file, "r");
-	    if (in == NULL)
-		adios (file, "unable to open");
-	}
-	else {
+	/* check if "file" is really stdin */
+	if (strcmp (file, "-") == 0) {
 	    in = stdin;
 	    file = "stdin";
+	} else {
+	    if ((in = fopen (file, "r")) == NULL)
+		adios (file, "unable to open");
 	}
 
 #ifndef	JLR
 	if (hdrflag) {
-	    time (&clock);
-	    printf ("Folder %-32s%s\n\n", file,
-		    dasctime (dlocaltime (&clock), TW_NULL));
+	    printf ("Folder %-32s%s\n\n", file, dtimenow (1));
 	}
 #endif /* JLR */
 
@@ -195,6 +190,10 @@ main (int argc, char **argv)
 	done (0);
     }
 
+    /*
+     * We are scanning a folder
+     */
+
     if (!msgp)
 	msgs[msgp++] = "all";
     if (!folder)
@@ -205,7 +204,7 @@ main (int argc, char **argv)
 	adios (maildir, "unable to change directory to");
 
     /* read folder and create message structure */
-    if (!(mp = m_gmsg (folder)))
+    if (!(mp = m_readfolder (folder)))
 	adios (NULL, "unable to read folder %s", folder);
 
     if (mp->hghmsg == 0)
@@ -215,20 +214,25 @@ main (int argc, char **argv)
     for (msgnum = 0; msgnum < msgp; msgnum++)
 	if (!m_convert (mp, msgs[msgnum]))
 	    done(1);
-    m_setseq (mp);	/* set the previous-sequence */
+    seq_setprev (mp);			/* set the Previous-Sequence */
 
-    m_replace (pfolder, folder);	/* update current folder   */
-    m_sync (mp);
-    m_update ();			/* update the context file */
+    m_replace (pfolder, folder);	/* update current folder         */
+    seq_save (mp);			/* synchronize message sequences */
+    m_update ();			/* update the context file       */
 
-    if ((cp = m_find(usequence))) {
-	/* set bits for each unseen sequence */
-	char *dp = NULL;
+    /*
+     * Get the sequence number for each sequence
+     * specified by Unseen-Sequence
+     */
+    if ((cp = m_find (usequence))) {
+	char *dp;
 
-	bits = 0;
-	for (ap = brkstring(dp = getcpy(cp), " ", "\n"); ap && *ap; ap++)
-	    bits |= m_seqflag(mp, *ap);
+	dp = getcpy(cp);
+	ap = brkstring (dp, " ", "\n");
+	for (i = 0; ap && *ap; i++, ap++)
+	    seqnum[i] = seq_getnum (mp, *ap);
 
+	num_unseen_seq = i;
 	if (dp)
 	    free(dp);
     }
@@ -241,8 +245,8 @@ main (int argc, char **argv)
 #endif
 
     for (msgnum = revflag ? mp->hghsel : mp->lowsel;
-	    (revflag ? msgnum >= mp->lowsel : msgnum <= mp->hghsel);
-	    msgnum += revflag ? (-1) : 1)
+	 (revflag ? msgnum >= mp->lowsel : msgnum <= mp->hghsel);
+	 msgnum += revflag ? (-1) : 1) {
 	if (is_selected(mp, msgnum)) {
 	    if ((in = fopen (cp = m_name (msgnum), "r")) == NULL) {
 #if 0
@@ -258,14 +262,21 @@ main (int argc, char **argv)
 
 #ifndef JLR
 	    if (hdrflag) {
-		time (&clock);
-		printf ("Folder %-32s%s\n\n", folder,
-			dasctime (dlocaltime (&clock), TW_NULL));
+		printf ("Folder %-32s%s\n\n", folder, dtimenow (1));
 	    }
 #endif /* JLR */
+
+	    /* Check if message is unseen */
+	    unseen = 0;
+	    for (i = 0; i < num_unseen_seq; i++) {
+		if (in_sequence(mp, seqnum[i], msgnum)) {
+		    unseen = 1;
+		    break;
+		}
+	    }
+
 	    switch (state = scan (in, msgnum, 0, nfs, width,
-			msgnum == mp->curmsg,
-			mp->msgstats[msgnum] & bits,
+			msgnum == mp->curmsg, unseen,
 			hdrflag ? folder : (char *) 0, 0L, 1)) {
 		case SCNMSG: 
 		case SCNENC: 
@@ -288,11 +299,13 @@ main (int argc, char **argv)
 	    if (ontty)
 		fflush (stdout);
 	}
+    }
+
 #ifdef LBL
-    m_sync (mp);	/* because formatsbr might have made changes */
+    seq_save (mp);	/* because formatsbr might have made changes */
 #endif
 
-    m_fmsg (mp);	/* free folder/message structure */
+    m_freefolder (mp);	/* free folder/message structure */
     if (clearflag)
 	clear_screen ();
 
