@@ -58,7 +58,8 @@ char *scanl = 0;			/* text of most recent scanline    */
 /*
  * prototypes
  */
-int sc_width (void);   /* from termsbr.c */
+int sc_width (void);			/* from termsbr.c */
+static int mh_fputs(char *, FILE *);
 
 
 int
@@ -115,7 +116,7 @@ scan (FILE *inb, int innum, int outnum, char *nfs, int width, int curflg,
 	}
 	FINDCOMP (cptr, "dtimenow");
 	if (cptr)
-	    cptr->c_text = getcpy(dtimenow ());
+	    cptr->c_text = getcpy(dtimenow (0));
 	nxtbuf = compbuffers = (char **) calloc((size_t) ncomps, sizeof(char *));
 	if (nxtbuf == NULL)
 	    adios (NULL, "unable to allocate component buffers");
@@ -129,7 +130,10 @@ scan (FILE *inb, int innum, int outnum, char *nfs, int width, int curflg,
 	    if ((*nxtbuf++ = malloc(rlwidth)) == NULL)
 		adios (NULL, "unable to allocate component buffer");
     }
-    /* each-message initialization */
+
+    /*
+     * each-message initialization
+     */
     nxtbuf = compbuffers;
     savecomp = used_buf;
     tmpbuf = *nxtbuf++;
@@ -138,24 +142,26 @@ scan (FILE *inb, int innum, int outnum, char *nfs, int width, int curflg,
     dat[4] = unseen;
 
     /*
-     * get the first field.  If the msg is non-empty and we're doing
-     * an "inc", open the output file.
+     * Get the first field.  If the message is non-empty
+     * and we're doing an "inc", open the output file.
      */
-    if ((state = m_getfld (FLD, name, tmpbuf, rlwidth, inb)) == FILEEOF)
+    if ((state = m_getfld (FLD, name, tmpbuf, rlwidth, inb)) == FILEEOF) {
 	if (ferror(inb)) {
 	    advise("read", "unable to"); /* "read error" */
 	    return SCNFAT;
-	} else
+	} else {
 	    return SCNEOF;
+	}
+    }
 
     if (outnum) {
-	if (outnum > 0) {	/* Fix from Van -- I'm not sure why... */
+	if (outnum > 0) {
 	    scnmsg = m_name (outnum);
-	    if (*scnmsg == '?')	/* msg num out of range */
+	    if (*scnmsg == '?')		/* msg num out of range */
 		return SCNNUM;
-	}
-	else
+	} else {
 	    scnmsg = "/dev/null";
+	}
 	if ((scnout = fopen (scnmsg, "w")) == NULL)
 	    adios (scnmsg, "unable to write");
 #ifdef RPATHS
@@ -189,7 +195,7 @@ scan (FILE *inb, int innum, int outnum, char *nfs, int width, int curflg,
 		 * buffer as the component temp buffer (buffer switching
 		 * saves an extra copy of the component text).
 		 */
-		if ((cptr = wantcomp[CHASH(name)]))
+		if ((cptr = wantcomp[CHASH(name)])) {
 		    do {
 			if (uleq(name, cptr->c_name)) {
 			    if (! cptr->c_text) {
@@ -206,6 +212,7 @@ scan (FILE *inb, int innum, int outnum, char *nfs, int width, int curflg,
 			    break;
 			}
 		    } while ((cptr = cptr->c_next));
+		}
 
 		while (state == FLDPLUS) {
 		    state = m_getfld (state, name, tmpbuf, rlwidth, inb);
@@ -233,7 +240,7 @@ scan (FILE *inb, int innum, int outnum, char *nfs, int width, int curflg,
 		 * a hack in m_getfld to save the amount of data it
 		 * returned in the global "msg_count".
 		 */
-	body: 	;
+body:;
 		while (state == BODY) {
 #ifdef LINUX_STDIO
 		    if (scnout->_IO_write_ptr == scnout->_IO_write_end) {
@@ -279,6 +286,7 @@ scan (FILE *inb, int innum, int outnum, char *nfs, int width, int curflg,
 		adios (NULL, "getfld() returned %d", state);
 	}
     }
+
     /*
      * format and output the scan line.
      */
@@ -301,8 +309,9 @@ finished:
 	else if (outnum > 0)
 	    dat[2] = ftell(scnout);
 
-	if ( (datecomp && ! datecomp->c_text) || (!size && !outnum)) {
+	if ((datecomp && !datecomp->c_text) || (!size && !outnum)) {
 	    struct stat st;
+
 	    fstat (fileno(inb), &st);
 	    if (!size && !outnum)
 		dat[2] = st.st_size;
@@ -320,13 +329,14 @@ finished:
 		}
 	    }
 	}
+
 #ifndef JLR
 	fmt_scan (fmt, scanl, slwidth, dat);
-#else	/* JLR */
+#else /* JLR */
 	fmt = fmt_scan (fmt, scanl, slwidth, dat);
 	if (!fmt)
 	    fmt = fmt_top;		/* reset for old format files */
-#endif	/* JLR */
+#endif /* JLR */
 
 	if (bodycomp)
 	    bodycomp->c_text = saved_c_text;
@@ -336,6 +346,7 @@ finished:
 
     FINDCOMP (cptr, "encrypted");
     encrypted = cptr && cptr->c_text;
+
     /* return dynamically allocated buffers to pool */
     while ((cptr = *savecomp++)) {
 	*--nxtbuf = cptr->c_text;
@@ -363,7 +374,7 @@ OfficialName (char *name)
 }
 
 
-int
+static int
 mh_fputs(char *s, FILE *stream)
 {
     char c;
