@@ -6,6 +6,7 @@
  */
 
 #include <h/mh.h>
+#include <fcntl.h>
 #include <errno.h>
 #include <signal.h>
 
@@ -279,7 +280,7 @@ main (int argc, char **argv)
     /*
      * check for "Aliasfile:" profile entry
      */
-    if (cp = m_find ("Aliasfile")) {
+    if ((cp = m_find ("Aliasfile"))) {
 	char *dp = NULL;
 
 	for (ap = brkstring(dp = getcpy(cp), " ", "\n"); ap && *ap; ap++) {
@@ -332,7 +333,7 @@ main (int argc, char **argv)
 	    adios (maildir, "unable to change directory to");
 
 	/* read folder and create message structure */
-	if (!(mp = m_gmsg (dfolder)))
+	if (!(mp = m_readfolder (dfolder)))
 	    adios (NULL, "unable to read folder %s", dfolder);
 
 	if (mp->hghmsg == 0)
@@ -342,7 +343,7 @@ main (int argc, char **argv)
 	for (msgnum = 0; msgnum < msgp; msgnum++)
 	    if (!m_convert (mp, msgs[msgnum]))
 		done (1);
-	m_setseq (mp);	/* set the previous-sequence */
+	seq_setprev (mp);	/* set the previous-sequence */
 
 	for (msgp = 0, msgnum = mp->lowsel; msgnum <= mp->hghsel; msgnum++) {
 	    if (is_selected (mp, msgnum)) {
@@ -353,9 +354,9 @@ main (int argc, char **argv)
 		mp->msgstats[msgnum] &= ~EXISTS;
 	    }
 	}
-	mp->msgflags |= SEQMOD;
 
-	m_sync (mp);
+	mp->msgflags |= SEQMOD;
+	seq_save (mp);
     }
 #ifdef WHATNOW
 go_to_it: ;
@@ -417,7 +418,7 @@ go_to_it: ;
 		int	in, out;
 		struct stat st;
 
-		if ((in = open (altmsg, 0)) == NOTOK)
+		if ((in = open (altmsg, O_RDONLY)) == NOTOK)
 		    adios (altmsg, "unable to open");
 		fstat(in, &st);
 		if ((out = creat (distfile, (int) st.st_mode & 0777)) == NOTOK)
