@@ -22,7 +22,7 @@ static struct swit switches[] = {
     { "nomoreproc", 3 },
 #define	LENSW                4
     { "length lines", 4 },
-#define	WIDSW                5
+#define	WIDTHSW              5
     { "width columns", 4 },
 #define	SHOWSW               6
     { "showproc program", 4 },
@@ -143,7 +143,7 @@ main (int argc, char **argv)
 
 		case PROGSW:
 		case LENSW:
-		case WIDSW:
+		case WIDTHSW:
 		    vec[vecp++] = --cp;
 		    if (!(cp = *argp++) || *cp == '-')
 			adios (NULL, "missing argument to %s", argp[-2]);
@@ -227,7 +227,7 @@ main (int argc, char **argv)
 	adios (maildir, "unable to change directory to");
 
     /* read folder and create message structure */
-    if (!(mp = m_gmsg (folder)))
+    if (!(mp = m_readfolder (folder)))
 	adios (NULL, "unable to read folder %s", folder);
 
     if (mp->hghmsg == 0)
@@ -241,8 +241,9 @@ main (int argc, char **argv)
     for (msgnum = mp->lowsel; msgnum <= mp->hghsel; msgnum++)
 	if (is_selected(mp, msgnum))
 	    set_unseen (mp, msgnum);
-    m_setseq (mp);
-    m_setvis (mp, 1);
+
+    seq_setprev (mp);	/* set the Previous-Sequence */
+    seq_setunseen (mp, 1);/* unset the Unseen-Sequence */
 
     if (mp->numsel > MAXARGS - 2)
 	adios (NULL, "more than %d messages for show exec", MAXARGS - 2);
@@ -253,8 +254,8 @@ main (int argc, char **argv)
 
     m_replace (pfolder, folder);	/* update current folder   */
     if (mp->hghsel != mp->curmsg)
-	m_setcur (mp, mp->hghsel);
-    m_sync (mp);			/* synchronize sequences   */
+	seq_setcur (mp, mp->hghsel);
+    seq_save (mp);			/* synchronize sequences   */
     m_update ();			/* update the context file */
 
     if (headersw && vecp == 2)
