@@ -286,9 +286,9 @@ main (int argc, char **argv)
     setbuf (stdin, NULL);
 
     /* Record the delivery time */
-    if ((now = dtwstime ()) == NULL)
+    if ((now = dlocaltimenow ()) == NULL)
 	adios (NULL, "unable to ascertain local time");
-    sprintf (ddate, "Delivery-Date: %s\n", dtimenow ());
+    sprintf (ddate, "Delivery-Date: %s\n", dtimenow (0));
 
     /*
      * Copy the message to a temporary file
