@@ -170,7 +170,7 @@ main (int argc, char **argv)
 	adios (maildir, "unable to change directory to");
 
     /* read folder and create message structure */
-    if (!(mp = m_gmsg (folder)))
+    if (!(mp = m_readfolder (folder)))
 	adios (NULL, "unable to read folder %s", folder);
 
     if (mp->hghmsg == 0)
@@ -180,7 +180,7 @@ main (int argc, char **argv)
     for (msgnum = 0; msgnum < msgp; msgnum++)
 	if (!m_convert (mp, msgs[msgnum]))
 	    done (1);
-    m_setseq (mp);	/* set the previous sequence */
+    seq_setprev (mp);	/* set the previous sequence */
 
     if ((nmsgs = read_hdrs (mp, datesw)) <= 0)
 	adios (NULL, "no messages to sort");
@@ -270,8 +270,8 @@ main (int argc, char **argv)
     rename_msgs (mp, dlist);
 
     m_replace (pfolder, folder);	/* update current folder         */
-    m_sync (mp);
-    m_fmsg (mp);			/* free folder/message structure */
+    seq_save (mp);			/* synchronize message sequences */
+    m_freefolder (mp);			/* free folder/message structure */
     m_update ();			/* update the context file       */
     done (0);
 }
@@ -283,7 +283,7 @@ read_hdrs (struct msgs *mp, char *datesw)
     struct tws tb;
     register struct smsg *s;
 
-    twscopy (&tb, dtwstime ());
+    twscopy (&tb, dlocaltimenow ());
 
     smsgs = (struct smsg *)
 	calloc ((size_t) (mp->hghsel - mp->lowsel + 2),
@@ -370,18 +370,19 @@ getws (char *datesw, int msg, struct smsg *smsg)
 	break;
     }
 
+    /*
+     * If no date component, then use the modification
+     * time of the file as its date
+     */
     if (!datecomp || (tw = dparsetime (datecomp)) == NULL) {
 	struct stat st;
 
-	admonish (NULL, "can't parse %s field in message %d",
-	      datesw, msg);
-
-	/* use the modify time of the file as its date */
+	admonish (NULL, "can't parse %s field in message %d", datesw, msg);
 	fstat (fileno (in), &st);
 	smsg->s_clock = st.st_mtime;
+    } else {
+	smsg->s_clock = dmktime (tw);
     }
-    else
-	smsg->s_clock = twclock (tw);
 
     if (subjsort) {
 	if (subjcomp) {
@@ -490,7 +491,7 @@ rename_chain (struct msgs *mp, struct smsg **mlist, int msg, int endmsg)
 
 	mp->msgstats[new] = mp->msgstats[old];
 	if (mp->curmsg == old)
-	    m_setcur (mp, new);
+	    seq_setcur (mp, new);
 
 	if (nxt == endmsg) 
 	    break;
