@@ -193,7 +193,7 @@ mbx_init (struct bboard *bp)
 	lkfclose (fp, bp->bb_info);
 	return lose ("unable to get information on BBoard %s", bp->bb_name);
     }
-    strcpy (bb_time, dtimenow ());
+    strcpy (bb_time, dtimenow (0));
     sprintf (bb_head, "BBoard-ID: %d\nBB-Posted: %s\n",
 	    bp->bb_maxima = ++ip->bb_maxima, bb_time);
 
@@ -331,7 +331,7 @@ lose (char *fmt, ...)
     char *bp, buffer[BUFSIZ];
 
     if (bb_fderr == NOTOK) {
-	if ((fd = open ("/dev/null", 0)) == NOTOK)
+	if ((fd = open ("/dev/null", O_RDONLY)) == NOTOK)
 	    adios (EX_OSERR, "/dev/null", "unable to open");
 	bb_fderr = copyfile (fd, bb_rept);
     }
@@ -381,7 +381,7 @@ notify (int fd)
 
     sprintf (buffer,
 	    "Date: %s\nFrom: %s\nTo: %s\nSubject: BBoards Failure\n\n",
-	    dtimenow (), bb_from, bb_from);
+	    dtimenow (0), bb_from, bb_from);
     if (rp_isbad (sm_wtxt (buffer, strlen (buffer))))
 	goto sm_err;
 
@@ -560,7 +560,7 @@ copyfile (int qd, char *tmpfil)
     if ((fd = creat (tmpfil, 0600)) == NOTOK)
 	adios (EX_CANTCREAT, tmpfil, "unable to create");
     close (fd);
-    if ((fd = open (tmpfil, 2)) == NOTOK)
+    if ((fd = open (tmpfil, O_RDWR)) == NOTOK)
 	adios (EX_NOINPUT, tmpfil, "unable to re-open");
 
     lseek (qd, (off_t)0, SEEK_SET);
