@@ -537,7 +537,7 @@ finish_headers (FILE *out)
     switch (msgstate) {
 	case normal: 
 	    if (!(msgflags & MDAT))
-		fprintf (out, "Date: %s\n", dtimenow ());
+		fprintf (out, "Date: %s\n", dtimenow (0));
 	    if (msgflags & MFRM)
 		fprintf (out, "Sender: %s\n", from);
 	    else
@@ -550,7 +550,7 @@ finish_headers (FILE *out)
 
 	case resent: 
 	    if (!(msgflags & MRDT))
-		fprintf (out, "Resent-Date: %s\n", dtimenow());
+		fprintf (out, "Resent-Date: %s\n", dtimenow(0));
 	    if (msgflags & MRFM)
 		fprintf (out, "Resent-Sender: %s\n", from);
 	    else
@@ -696,7 +696,7 @@ make_bcc_file (void)
 	adios (bccfil, "unable to create");
     chmod (bccfil, 0600);
 
-    fprintf (out, "Date: %s\n", dtimenow ());
+    fprintf (out, "Date: %s\n", dtimenow (0));
     fprintf (out, "From: %s\n", signature);
     if (subject)
 	fprintf (out, "Subject: %s", subject);
@@ -704,7 +704,7 @@ make_bcc_file (void)
     fflush (out);
 
     if (filter == NULL) {
-	if ((fd = open (tmpfil, 0)) == NOTOK)
+	if ((fd = open (tmpfil, O_RDONLY)) == NOTOK)
 	    adios (NULL, "unable to re-open");
 	cpydgst (fd, fileno (out), tmpfil, bccfil);
 	close (fd);
@@ -738,7 +738,7 @@ make_bcc_file (void)
 	}
     }
 
-    fseek (out, 0L, 2);
+    fseek (out, 0L, SEEK_END);
     fprintf (out, "\n------- End of Blind-Carbon-Copy\n");
     fclose (out);
 }
