@@ -265,7 +265,7 @@ char   *str;
 
 	case OK: 
 	    close (0);
-	    open ("/dev/null", 0);
+	    open ("/dev/null", O_RDONLY);
 	    dup2 (pd[1], 1);
 	    dup2 (pd[1], 2);
 	    close (pd[0]);
