@@ -6,6 +6,7 @@
  */
 
 #include <h/mh.h>
+#include <fcntl.h>
 #include <signal.h>
 
 #ifdef MIME
@@ -64,7 +65,7 @@ static char *myprompt = "\nWhat now? ";
  * static prototypes
  */
 static int editfile (char **, char **, char *, int, struct msgs *, char *, char *);
-static sendfile (char **, char *, int);
+static int sendfile (char **, char *, int);
 static void sendit (char *, char **, char *, int);
 static int whomfile (char **, char *);
 
@@ -161,8 +162,7 @@ WhatNow (int argc, char **argv)
 	ed = NULL, nedit++;
     if ((cp = getenv ("mhuse")) && *cp)
 	use = atoi (cp);
-    if (!nedit
-	    && editfile (&ed, NULL, drft, use, NULLMP, msgnam, NULL) < 0)
+    if (!nedit && editfile (&ed, NULL, drft, use, NULLMP, msgnam, NULL) < 0)
 	done (1);
 
     sprintf (prompt, myprompt, invo_name);
@@ -293,9 +293,9 @@ editfile (char **ed, char **arg, char *file, int use,
 	    umask(oumask);		/* PJS: else symlinks are world 'r' */
 #endif
 	    slinked = 1;
-	}
-	else
+	} else {
 	    slinked = 0;
+	}
 #else /* not HAVE_LSTAT */
 	link (altpath, linkpath);
 #endif /* not HAVE_LSTAT */
@@ -397,22 +397,18 @@ editfile (char **ed, char **arg, char *file, int use,
 static int
 copyf (char *ifile, char *ofile)
 {
-    register int i;
-    int in, out;
+    int i, in, out;
     char buffer[BUFSIZ];
 
-    if ((in = open (ifile, 0)) == NOTOK)
+    if ((in = open (ifile, O_RDONLY)) == NOTOK)
 	return NOTOK;
-    if ((out = open (ofile, 1)) == NOTOK || ftruncate (out, 0) == NOTOK) {
-	if (out != NOTOK) {
-	    admonish (ofile, "unable to truncate");
-	    close (out);
-	}
+    if ((out = open (ofile, O_WRONLY | O_TRUNC)) == NOTOK) {
+	admonish (ofile, "unable to open and truncate");
 	close (in);
 	return NOTOK;
     }
 
-    while ((i = read (in, buffer, sizeof buffer)) > OK)
+    while ((i = read (in, buffer, sizeof(buffer))) > OK)
 	if (write (out, buffer, i) != i) {
 	    advise (ofile, "may have damaged");
 	    i = NOTOK;
@@ -421,7 +417,6 @@ copyf (char *ifile, char *ofile)
 
     close (in);
     close (out);
-
     return i;
 }
 #endif /* HAVE_LSTAT */
@@ -431,7 +426,7 @@ copyf (char *ifile, char *ofile)
  * SEND
  */
 
-static
+static int
 sendfile (char **arg, char *file, int pushsw)
 {
     pid_t child_id;
@@ -442,11 +437,14 @@ sendfile (char **arg, char *file, int pushsw)
     if ((cp = m_find ("automhnproc"))
 	    && !getenv ("NOMHNPROC")
 	    && mhnfile (file)
-	    && (i = editfile (&cp, NULL, file, NOUSE, NULLMP, NULL,
-			      NULL)))
+	    && (i = editfile (&cp, NULL, file, NOUSE, NULLMP, NULL, NULL)))
 	return 0;
 #endif
 
+    /*
+     * If the sendproc is the nmh command `send', then we call
+     * those routines directly rather than exec'ing the command.
+     */
     if (strcmp (sp = r1bindex (sendproc, '/'), "send") == 0) {
 	cp = invo_name;
 	sendit (invo_name = sp, arg, file, pushsw);
