@@ -54,9 +54,9 @@ main (int argc, char **argv)
     if ((cp = m_find (invo_name)) != NULL) {
 	ap = brkstring (cp = getcpy (cp), " ", "\n");
 	ap = copyip (ap, arguments);
-    }
-    else
+    } else {
 	ap = arguments;
+    }
     copyip (argv + 1, ap);
     argp = arguments;
 
@@ -155,9 +155,11 @@ main (int argc, char **argv)
 
     closefds (3);
 
-    if (distsw)
+    if (distsw) {
 	for (i = 0; (child_id = fork()) == NOTOK && i < 5; i++)
 	    sleep (5);
+    }
+
     switch (distsw ? child_id : OK) {
 	case NOTOK:
     	    advise (NULL, "unable to fork, so checking directly...");
