@@ -547,7 +547,7 @@ static intWINinit (nprog) {
 	else
 	    adios (NULL, "not a window");
 
-    if ((dfd = open ("/dev/ttyw0", 2)) == NOTOK)
+    if ((dfd = open ("/dev/ttyw0", O_RDWR)) == NOTOK)
 	adios ("/dev/ttyw0", "unable to open");
 
     if ((twd = GetTopWindow (dfd)) == NOTOK)
