@@ -48,9 +48,9 @@ struct addrent {
 #define	a_net  un.un_net
 #define	a_addr un.un_addr
 
-static struct addrent *ne, *nz;
+static struct addrent *n1, *n2;
 static struct addrent nets[MAXNETS];
-static struct addrent *he, *hz;
+static struct addrent *h1, *h2;
 static struct addrent hosts[MAXHOSTS];
 
 #ifdef KPOP
@@ -132,8 +132,11 @@ client (char *args, char *protocol, char *service, int rproto, char *response)
 	*ap = NULL;
     }
 
-    nz = (ne = nets) + sizeof(nets) / sizeof(nets[0]);
-    hz = (he = hosts) + sizeof(hosts) / sizeof(hosts[0]);
+    n1 = nets;
+    n2 = nets + sizeof(nets) / sizeof(nets[0]);
+
+    h1 = hosts;
+    h2 = hosts + sizeof(hosts) / sizeof(hosts[0]);
 
     for (ap = arguments; *ap; ap++) {
 	if (**ap == '\01') {
@@ -194,11 +197,11 @@ rcaux (struct servent *sp, struct hostent *hp, int rproto, char *response)
     int rem;
 #endif	/* KPOP */
 
-    for (ap = nets; ap < ne; ap++)
+    for (ap = nets; ap < n1; ap++)
 	if (ap->a_addrtype == hp->h_addrtype && inet (hp, ap->a_net))
 	    return NOTOK;
 
-    for (ap = hosts; ap < he; ap++)
+    for (ap = hosts; ap < h1; ap++)
 	if (ap->a_addrtype == hp->h_addrtype
 		&& memcmp(ap->a_addr, hp->h_addr, hp->h_length) == 0)
 	    return NOTOK;
@@ -216,11 +219,11 @@ rcaux (struct servent *sp, struct hostent *hp, int rproto, char *response)
 	    case ENETDOWN: 
 	    case ENETUNREACH: 
 		close (sd);
-		if (ne < nz) {
-		    ne->a_addrtype = hp->h_addrtype;
+		if (n1 < n2) {
+		    n1->a_addrtype = hp->h_addrtype;
 		    memcpy((char *) &in, hp->h_addr, sizeof(in));
-		    ne->a_net = inet_netof (in);
-		    ne++;
+		    n1->a_net = inet_netof (in);
+		    n1++;
 		}
 		return OOPS1;
 
@@ -228,10 +231,10 @@ rcaux (struct servent *sp, struct hostent *hp, int rproto, char *response)
 	    case ECONNREFUSED: 
 	    default: 
 		close (sd);
-		if (he < hz) {
-		    he->a_addrtype = hp->h_addrtype;
-		    memcpy(he->a_addr, hp->h_addr, hp->h_length);
-		    he++;
+		if (h1 < h2) {
+		    h1->a_addrtype = hp->h_addrtype;
+		    memcpy(h1->a_addr, hp->h_addr, hp->h_length);
+		    h1++;
 		}
 		return NOTOK;
 	}
