@@ -25,8 +25,8 @@ struct yysvf {
 };
 
 struct yywork { 
-	YYTYPE	verify;
-	YYTYPE	advance; 
+    YYTYPE verify;
+    YYTYPE advance; 
 }; 
 
 extern int yyvstop[];
@@ -64,23 +64,23 @@ static char case_map[] = {
 };
 #endif	/* ONECASE */
 
-lex_string( strptr, start_cond)
-	char	**strptr;
-	int	start_cond;
-{
-	register struct yysvf *state, **lsp;
-	register struct yywork *tran;
-	register int statenum;
-	register int ch;
-	register char	*cp = *strptr;
-	register int	*found;
-	struct	yysvf *yylstate[YYLMAX];
 
-	/* start off machines */
-	lsp = yylstate;
-	statenum = 1 + start_cond;
-	state = yysvec + statenum;
-	for (;;){
+int
+lex_string (char **strptr, int start_cond)
+{
+    register struct yysvf *state, **lsp;
+    register struct yywork *tran;
+    register int statenum;
+    register int ch;
+    register char *cp = *strptr;
+    register int *found;
+    struct yysvf *yylstate[YYLMAX];
+
+    /* start off machines */
+    lsp = yylstate;
+    statenum = 1 + start_cond;
+    state = yysvec + statenum;
+    for (;;) {
 # ifdef LEXDEBUG
 		if (debug) {
 			fprintf(stderr,"%d ",statenum - 1);
